
/****************************************************************************
** Form implementation generated from reading ui file './aboutDlg.ui'
**
** Created: Sun Dec 17 12:39:11 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "aboutDlg.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qframe.h>
#include <qtextedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const char* const img0_aboutDlg[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};

static const char* const img1_aboutDlg[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img2_aboutDlg[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img3_aboutDlg[] = { 
"116 21 19 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"l c #034c95",
"j c #065099",
"f c #08539e",
"k c #0b57a2",
"m c #0e5aa6",
"e c #115eaa",
"q c #115fab",
"b c #1361ae",
"n c #1665b2",
"h c #1968b6",
"o c #1c6cbb",
"i c #1e6fbf",
"p c #2172c3",
"g c #2476c7",
"d c #2779cb",
"c c #297dcf",
"....................................................................................................#...............",
".................................................................................................................a..",
"....................................................................................................................",
"....................................................................................................................",
"....................................................................................................................",
".......bcd...........eccdf............................................gce...................ecg.....................",
"##.....hci..........jcccck...........................................jcck............#......hci.....................",
".......gcb..........ecg.l...........................................................................................",
"......lcce.icbiccb.hccccm.nccch...hceicopcbpcpledci...bdccil.bcccccp.bcp..miccpm..kcgbdcpj..dcm.....................",
"......kccj.gccccccjiccccjpccccci..icdccfdcccccpcccck.nccccco.occccco.och.ecccccck.ecccccch.fccj.....................",
"......bcd.jccillccj.pce.bcdm.mccf.dcpf.fcch.hcdm.dck.....ecp....hcgj.gcb.dci..ico.hcce.nch.ecd......................",
"......hci.kcdl.kcd..dcj.pcn...dcmjccf..ecg..hcn.jccl.fnndcch...icpj.lcckmcdl..bcp.icn..icb.nci......................",
"......gcn.bci..bci.fcd..dcm..fccfkcg...bco..gck.mcg.mcpe.gce..icpl..kcclbcp...oco.dck..dck.icn......................",
".....lccqahcn..hch.eci..ico.licp.bch...icb.lccl.bco.hcn.bccjlpci....bcg.kcdf.eccmjccl.jccj.dce..a...................",
".....kccj.pce..ice.nch..ecccccdf.hcb...gcm.kcg..hcb.bcccccd.hcccccg.hco..pccccco.mcg..kcg.jccf......................",
".....bcd..dcf..dcf.ice...egccif..pcm..lccj.bco..gcm.liccncd.iccccch.pcb..loccdb..bco..bco.mcd.......................",
"..............................................................................................a.....................",
"....................................................................................................................",
"....................................................................................................................",
"....................................................................................................................",
"...................................................................................................................."};

static const char* const img4_aboutDlg[] = { 
"34 31 4 1",
"a c #004894",
"b c #004c94",
"# c #004c9c",
". c #ffffff",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba"};

static const char* const img5_aboutDlg[] = { 
"51 16 89 2",
".R c #000000",
"#w c #000400",
"#. c #000810",
".o c #000c10",
".M c #000c18",
".n c #001020",
".m c #001429",
".l c #001831",
".p c #001c39",
".k c #002041",
".j c #00244a",
".g c #002c5a",
".i c #003062",
".f c #00346a",
".e c #00386a",
".d c #003873",
".9 c #003c73",
".c c #003c7b",
".h c #004083",
".b c #00448b",
".# c #004894",
".a c #004c94",
"Qt c #004c9c",
".5 c #080808",
".0 c #080c10",
".V c #080c18",
".G c #081018",
"#t c #101010",
"#l c #101410",
".z c #101820",
"#n c #181418",
"#h c #181818",
".U c #181c18",
".q c #182431",
".Z c #201c20",
"#c c #202020",
"#v c #202420",
".8 c #292429",
".3 c #312c31",
".L c #313031",
"#u c #313431",
".Y c #393839",
".4 c #393c39",
"#k c #413c41",
".N c #414041",
".F c #4a444a",
"#g c #4a484a",
"#b c #4a4c4a",
".T c #524c52",
".7 c #5a595a",
"#s c #625d62",
".r c #626162",
".2 c #626562",
".A c #62656a",
".K c #6a656a",
".y c #6a696a",
".W c #6a6d73",
".X c #7b757b",
"#i c #7b797b",
"#f c #837d83",
".E c #838183",
".S c #838583",
"#a c #8b858b",
".s c #8b898b",
"#r c #8b8d8b",
".6 c #948d94",
"#d c #949194",
".x c #9c999c",
"#p c #9c9d9c",
".J c #a49da4",
".t c #a4a1a4",
".B c #aca5ac",
"## c #acaaac",
".D c #acaeac",
"#o c #b4aeb4",
".O c #b4b2b4",
".1 c #b4b6b4",
"#e c #bdb6bd",
".I c #bdbabd",
".H c #bdbebd",
".w c #c5bec5",
".P c #c5c2c5",
".Q c #c5c6c5",
".C c #cdc6cd",
".u c #cdcacd",
".v c #d5ced5",
"#j c #d5d2d5",
"#m c #eee6ee",
"#q c #eeeaee",
"Qt.#.a.#Qt.#.a.#Qt.#.a.#.#.b.b.c.c.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.f.g",
".#.#.#.#.#.#.#.#.#.#.b.h.d.i.j.k.l.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.n.o",
".a.#Qt.#.a.#Qt.#.#.c.f.j.p.n.q.r.s.t.u.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.w.x.y",
".#.#.#.#.#.#.b.h.i.j.n.z.A.B.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.C.D.E.F",
"Qt.#.a.#.#.b.c.j.m.G.A.H.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.I.J.K.L",
".#.#.#.#.h.f.p.M.N.O.P.Q.P.C.P.Q.R.R.R.R.R.C.P.Q.P.C.P.Q.P.C.P.Q.P.C.R.R.P.C.P.Q.P.C.P.Q.P.C.P.O.S.T.U",
".a.#.#.h.g.m.V.W.P.P.P.P.P.P.P.P.R.R.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.w.t.X.Y.Z",
".#.#.h.g.n.0.S.P.H.P.H.P.H.P.H.P.R.R.H.P.H.P.H.P.R.R.R.P.H.R.R.R.H.P.R.R.H.P.H.P.H.P.H.P.H.P.1.x.2.3.4",
"Qt.b.f.m.5.E.w.H.w.H.w.H.w.H.w.H.R.R.R.R.R.H.w.R.R.H.w.H.R.R.w.H.w.H.R.R.w.H.w.H.w.H.w.H.w.H.O.6.7.8.y",
".b.9.p#..y.I.I.I.I.I.I.I.I.I.I.I.R.R.I.I.I.I.I.I.R.R.I.I.R.R.I.I.I.I.R.R.I.I.I.I.I.I.I.I.I.I###a#b#c#d",
".h.j.n.N.I#e.I#e.I#e.I#e.I#e.I#e.R.R.I#e.I#e.I#e.I.R.R#e.R.R.I#e.I#e.R.R.I#e.I#e.I#e.I#e.I#e.B#f#g#h.I",
".i.m.0##.O.1.O#e.O.1.O#e.O.1.O#e.R.R.R.R.R.1.O.R.R.R.O#e.O.R.R.R.O.1.R.R.O.1.O#e.O.1.O#e.O.1.t#i.4#h#j",
".j#..y.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.t#i#k#l#m",
".n#n##.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O#p.X.Y#n#q",
".L#b.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.E#s.L#t.P",
"#u#v.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z#h#n.5#w.2"};

static const char* const img6_aboutDlg[] = { 
"28 31 202 2",
"ao c #000008",
"#k c #000810",
"#d c #000c18",
"af c #001018",
"#j c #001020",
"#c c #001429",
"#S c #001831",
"#5 c #001c39",
"#i c #002041",
"#b c #00244a",
"#I c #002852",
"#h c #002c5a",
"#a c #003062",
"#4 c #003462",
"#y c #00346a",
"#H c #003873",
"#g c #003c7b",
"## c #004083",
"#x c #004483",
"#. c #00448b",
"#p c #00488b",
".9 c #004894",
"#o c #004c94",
".8 c #004c9c",
"#q c #080810",
"aE c #101820",
"aw c #102439",
"#6 c #182020",
".N c #202020",
".H c #202420",
"ax c #202429",
".G c #292829",
".7 c #292c29",
".V c #312c31",
".F c #313031",
".2 c #313431",
".E c #393439",
".1 c #393839",
".M c #393c39",
"#T c #393c41",
".D c #414041",
".O c #414441",
"#l c #41444a",
"aj c #4195ee",
".C c #4a444a",
".W c #4a4c4a",
"aB c #4a99ee",
"ap c #525052",
".6 c #525552",
"#J c #52555a",
"#8 c #52a1ee",
".B c #5a555a",
".0 c #5a595a",
".L c #5a5d5a",
".w c #626162",
".v c #626562",
"a7 c #62797b",
"bh c #6a656a",
".x c #6a696a",
".u c #6a6d6a",
"#F c #6a9dc5",
"al c #6aaeee",
".t c #737173",
"bc c #738d94",
"a4 c #73aed5",
"a# c #73b2f6",
".K c #7b797b",
".3 c #7b7d7b",
".Z c #7b7d83",
"b# c #7b999c",
"#B c #7ba1c5",
"aG c #7baad5",
"aQ c #7bb2d5",
"a. c #7bb6ee",
".s c #837d83",
".5 c #838183",
".r c #83858b",
"bf c #839594",
"#7 c #83a5cd",
"#E c #83aad5",
"#L c #83b2d5",
"#U c #83b6cd",
"#Y c #83bef6",
".A c #8b858b",
".P c #8b898b",
"ag c #8b8d8b",
"a1 c #8baab4",
"#Q c #8bb6de",
"ar c #8bbad5",
"ay c #8bbed5",
"#2 c #8bbede",
"ad c #8bc2d5",
"#X c #8bc2f6",
"an c #8bc6de",
"aZ c #8bc6e6",
"a6 c #949194",
".q c #94959c",
"#D c #94b6d5",
"bd c #94bec5",
"#u c #94bed5",
"az c #94bee6",
"#A c #94c2d5",
"aS c #94c2de",
"#R c #94c6de",
"aX c #94cae6",
"aY c #94cee6",
".4 c #9c959c",
".J c #9c9da4",
"b. c #9caaac",
"#C c #9cb6d5",
"#G c #9cc6de",
"aT c #9cc6e6",
"a2 c #9ccacd",
"#v c #9ccade",
"aL c #9cceee",
"aD c #9cd2e6",
"aK c #9cd6e6",
"#e c #a49da4",
".p c #a4a1a4",
"ah c #a4bede",
"as c #a4cae6",
"#9 c #a4caf6",
".Y c #acaaac",
"a8 c #accecd",
"aW c #acdae6",
".j c #b4b2b4",
".Q c #b4b6b4",
".k c #b4b6bd",
"#3 c #b4dae6",
"a0 c #b4daee",
"aU c #b4deff",
".i c #bdb6bd",
".h c #bdbabd",
".I c #bdbebd",
"be c #bddede",
"a9 c #bddee6",
"aF c #bddeee",
"aJ c #bddef6",
"ac c #bde6ff",
"#m c #c5bec5",
".g c #c5c2c5",
".f c #c5c6c5",
"#V c #c5cee6",
"#M c #c5d2e6",
"bg c #c5dede",
"aO c #c5def6",
"#t c #c5e2ee",
"aR c #c5e6e6",
"bb c #c5e6ee",
"a3 c #c5eaee",
"a5 c #c5eaff",
"#P c #c5eeff",
".R c #cdc6cd",
".o c #cdcacd",
".S c #cdcecd",
"#w c #cde6ee",
"#K c #cdeaee",
"am c #cdeeff",
"#1 c #cdf6ff",
".e c #d5ced5",
"#r c #d5d2d5",
".d c #d5d6d5",
"ak c #d5e6f6",
"#z c #d5eaee",
"ai c #d5eaff",
"aP c #d5eef6",
"aC c #d5eeff",
"aM c #d5faff",
".z c #dedade",
".U c #dedede",
".n c #dedee6",
"#s c #deeaee",
"av c #deeeee",
"#0 c #def6f6",
"#O c #defaff",
".c c #e6dee6",
"aq c #e6e2e6",
"#f c #e6e6e6",
"#n c #e6eaee",
"ba c #e6eeee",
"ae c #e6eef6",
"#Z c #e6f2f6",
"au c #e6f6ff",
"aH c #e6faf6",
"ab c #e6faff",
".X c #eee6ee",
".b c #eeeaee",
".m c #eeeeee",
"aV c #eeeef6",
"#W c #eef2ff",
"aI c #eef6ff",
"aN c #eefaff",
"at c #eeffff",
".y c #f6eef6",
".T c #f6f2f6",
".a c #f6f6ff",
"aA c #f6faf6",
"#N c #f6ffff",
".l c #fff6ff",
".# c #fffaff",
"aa c #fffff6",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.i.j.i.k",
"QtQtQtQtQtQtQtQtQtQtQtQt.#.l.m.n.o.i.p.q.r.s.t.u.v.v.w.x",
"QtQtQtQtQtQtQtQtQtQtQt.l.y.z.g.p.A.x.B.C.D.E.F.G.G.H.G.G",
"QtQtQtQtQtQtQtQtQt.#.b.z.I.J.K.L.M.G.N.G.O.u.P.p.Q.R.S.o",
"QtQtQtQtQtQtQt.#.T.U.f.J.s.B.M.N.V.W.P.h.X.b.m.b.y.b.m.b",
"QtQtQtQtQtQt.a.b.S.Y.Z.0.1.N.2.3.h.b.b.b.b.b.b.b.b.b.b.b",
"QtQtQtQtQt.l.X.g.4.v.D.N.E.5.e.b.m.b.y.b.m.b.y.b.m.b.y.b",
"QtQtQtQt.T.c.i.P.6.7.N.x.f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".8.9.9#.###a#b#c#d.G#e#f.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".9.9#.#g#h#i#j#k#l#m.b.b.b.b#n#n#n#n#n.b.b.b.b.b.b.b.b.b",
"#o#p###a#i#j#q.0#r.b.y.b.m#s#t#u#u#v#w#n.m.b.y.b.m.b.y.b",
"#.#x#y#b#j#k.L.z.b.b.b.b#z#A#B#C#D#E#F#G#z.b.b.b.b.b.b.b",
"#.#H#I#c#k#J.U.b.y.b.m#K#L#MQtQt#N#O#P#Q#R#s.m.b.y.b.m.b",
"#H#h#S#d#T.e.b.b.b.b#s#U#V#W#X#Y#ZQt#0#1#2#3#n.b.b.b.b.b",
"#4#5#j#6.i.b.y.b.m#n#t#7Qt#8#9a.a#aaQtabacadae.b.m.b.y.b",
"#5af#qag.b.b.b.b.b#n#AahaiajaaakalQtaa#Naman#z.b.b.b.b.b",
"#kaoapaq.y.b.m.b.y#narasata.Qtaka#aaQt#Nau#Rav.b.y.b.m.b",
"awax.Q.b.b.b.b.b.b#nayaz#OQtaaaAaB#WaaQtaCaD#s.b.b.b.b.b",
"aE.x.b.b.m.b.y.b.m#naFaG#1aHQtaaak#8aIQtaJaKae.b.m.b.y.b",
"ax#m.b.b.b.b.b.b.b.b#sayaLaMaNQtaaaOaaQtaPaQaR.b.b.b.b.b",
".waq.m.b.y.b.m.b.y.b.m#zaSaTamab#NaNQtaaabaUay#zaV.b.m.b",
".p.b.b.b.b.b.b.b.b.b.b.b#zaWanaXaYaZa0#OaN#Na1a2#s.b.b.b",
"#r.b.y.b.m.b.y.b.m.b.y.b.m#nae#zava3a4a5Qtaqa6a7a8#n.y.b",
"#f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#na9aQb..g.o.5b##s.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bbabbbc.5.R.pbd#s.m.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#nbeb#bfbgaR#n.b.b",
".m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bba#z#w#zba.b.y.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m",
".xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh"};

static const char* const img7_aboutDlg[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img8_aboutDlg[] = { 
"149 74 3255 2",
"oc c #000000",
"pl c #000001",
"FR c #000104",
"qI c #00081a",
"yJ c #000961",
"yK c #000962",
"yI c #000a62",
"zY c #000e61",
"ur c #000e63",
"tC c #000f67",
"zS c #001066",
"zT c #001165",
"yH c #00116b",
"AY c #001265",
"A5 c #001266",
"uw c #001269",
"uv c #001365",
"zX c #001668",
"B8 c #00166a",
"rx c #00173a",
"zU c #001869",
"zW c #00186a",
"zV c #00196a",
"vj c #00196c",
"ry c #010000",
"BD c #010100",
"qj c #010101",
"tD c #01146b",
"zZ c #01196e",
"uf c #01306a",
"ML c #020103",
"qV c #020202",
"yL c #021972",
"sv c #022651",
"s# c #024795",
"tu c #030201",
"pk c #030202",
"tt c #030303",
"Em c #030304",
"Fq c #030404",
"us c #031b6b",
"A4 c #031c6d",
"Oy c #040402",
"AB c #040403",
"sE c #040404",
"Gq c #04060b",
"uu c #041e6d",
"Ce c #042175",
"A3 c #042272",
"Nw c #050401",
"pW c #050404",
"qJ c #050505",
"Nf c #050d15",
"ut c #051f6f",
"Dn c #05206e",
"AZ c #052171",
"D. c #060606",
"Cd c #062070",
"A2 c #062373",
"tk c #06315f",
".k c #0636b7",
"rj c #063d81",
"o8 c #064694",
"s. c #070502",
"ts c #070707",
"Hn c #07080c",
"A0 c #072373",
"qK c #080808",
"A1 c #082373",
"DZ c #090706",
"GX c #090807",
"D# c #090909",
"vp c #092371",
".e c #0933b1",
"on c #0a0808",
"qW c #0a0a0a",
"Dt c #0a0d10",
"tB c #0a1d73",
".f c #0a3bbb",
"MX c #0b0908",
"O7 c #0b0a0d",
"vc c #0b0b0b",
"tl c #0c0906",
"EM c #0c0908",
"Nx c #0c0b0b",
"ww c #0c0c0c",
"Nv c #0c0e12",
"B9 c #0c2976",
"Cc c #0c2977",
"ul c #0d0c0b",
"Hp c #0d0d0c",
"rZ c #0d0d0d",
"rK c #0d0f11",
"FS c #0d1112",
"uK c #0e0e0e",
"O9 c #0e0e0f",
"Df c #0e2a76",
"wg c #0e2a77",
"qv c #0e3365",
"Ou c #0f0e0e",
"nt c #0f0f0f",
"Da c #0f0f10",
"KC c #0f1112",
"vq c #0f2d7f",
"G6 c #100d00",
"Jb c #10100d",
"Fc c #10100f",
"q8 c #101010",
"O8 c #101116",
"C. c #102a78",
"Cb c #102b78",
"C# c #102c78",
"PL c #110e08",
"vF c #111111",
"Ip c #111112",
"Ca c #112c79",
".j c #1142c2",
"dk c #1169ff",
"Pa c #12100f",
"EH c #121110",
"zL c #121111",
"qa c #121212",
"Er c #122e7c",
"yA c #131211",
"Po c #131212",
"vG c #131313",
"Jp c #131414",
"zM c #131619",
"Fb c #13181d",
"Dm c #13307b",
".l c #1334ae",
"uk c #141414",
"pF c #14273d",
"EC c #142f7a",
"vk c #142f7b",
"vo c #14307c",
"ob c #143d77",
"sZ c #145fb1",
"MY c #151515",
"O# c #151617",
"Dl c #15317c",
"yG c #153289",
".g c #1546c5",
"v. c #154981",
"o9 c #161615",
"tL c #161616",
"vn c #16317c",
"vm c #16317d",
"vl c #16327d",
"Dk c #16337e",
"EO c #163d67",
".h c #1647c7",
"tU c #16599f",
"zx c #171717",
"MW c #171a21",
"CO c #171c20",
"FJ c #17327e",
".i c #1748c8",
"BT c #181818",
"Kh c #181a1b",
"Hq c #181b1d",
"Dg c #18337e",
"wa c #18347e",
"De c #183583",
".K c #1841ba",
"ax c #184acb",
"cJ c #185ee1",
"uJ c #191919",
"Fa c #192128",
"Gf c #192b3e",
"Dj c #19357e",
"Dh c #19357f",
"cY c #1951d2",
"eO c #195ad1",
"FM c #1a1a1a",
"Di c #1a357f",
"uq c #1a3686",
".2 c #1a46c6",
"Ng c #1b1b1a",
"Ee c #1b1b1b",
"L2 c #1b202d",
"EB c #1b3781",
"iZ c #1b63d3",
"pV c #1b66bd",
"P3 c #1c1b1a",
"Oa c #1c1c1c",
"tE c #1c3287",
"Es c #1c3781",
"yt c #1d1d1d",
"zo c #1d2023",
"GK c #1d3981",
"pz c #1e1e1e",
"qX c #1e2226",
"xi c #1e3881",
"EA c #1e3982",
"#7 c #1e42b8",
"Qs c #1e4876",
"eX c #1e5fd0",
"L1 c #1f1e1c",
"Ob c #1f1f1f",
"Et c #1f3a83",
"v4 c #201f1f",
"pX c #202020",
"v5 c #202120",
"GA c #203a83",
"wf c #203b83",
"Ez c #203b84",
"ED c #203d89",
"bg c #204dbf",
"dw c #205fd8",
"tT c #211e1d",
"Ib c #212121",
"Eu c #213b83",
"Ey c #213d84",
"Ev c #213d85",
"yM c #214195",
"dm c #2156c4",
"aX c #215eda",
"nh c #222222",
"FI c #223c84",
"Ew c #223d85",
"we c #223e85",
"EN c #225691",
".J c #225bd2",
"j1 c #226bd3",
"HR c #232323",
"Im c #232326",
"oo c #23282f",
"QH c #23313f",
"Ex c #233e85",
"wb c #233e86",
"cu c #2365de",
"su c #237cf3",
"sY c #242423",
"In c #242424",
"DY c #242526",
".u c #2443b5",
".v c #244dbf",
"#J c #2453cb",
"PO c #252423",
"NW c #252832",
"EG c #252a2e",
"wc c #253f86",
"wd c #254086",
"Lz c #262626",
"FA c #264087",
"w# c #26438b",
"a1 c #2649ba",
"gF c #265cbc",
"K6 c #272727",
"Gu c #272b2e",
"um c #272b30",
"FH c #274288",
"AX c #274795",
"GN c #282828",
"Fw c #282e32",
".d c #283cad",
"HM c #284188",
"FB c #284389",
"c9 c #2866d5",
"mt c #286fd1",
"g. c #286fde",
"zp c #292726",
"mw c #292929",
"Ed c #292a2a",
"Iq c #292e32",
"cj c #2970e7",
"ri c #2a2622",
"q# c #2a2a2a",
"Lr c #2a2c2f",
"JN c #2a2d30",
"w8 c #2a2e30",
"FC c #2a448a",
"FG c #2a458a",
"bH c #2a53bb",
"i# c #2a60bb",
"bc c #2a69e0",
"od c #2b2b2b",
"Mb c #2b2d2e",
"#e c #2b43ae",
"HA c #2b448b",
"xc c #2b458a",
"xb c #2b458b",
"fY c #2b73e3",
"lj c #2b75db",
"Jo c #2c2b2b",
"q7 c #2c2c2c",
"FD c #2c468b",
"hG c #2c76e7",
"rz c #2d2d2d",
"B4 c #2d3237",
"vd c #2d333a",
"FE c #2d468b",
"FF c #2d478b",
"zR c #2d4b9d",
"EK c #2e2e2e",
"yg c #2e468c",
".L c #2e47ad",
"#q c #2e4cb2",
"pj c #2f2f2f",
"Lc c #2f3030",
"FV c #2f3035",
"N7 c #2f364a",
"Ny c #303030",
"GJ c #30498c",
"GB c #30498d",
"xh c #30498e",
".8 c #304bb7",
"bZ c #3073eb",
"G5 c #313236",
".m c #3141b0",
"GI c #314a8e",
"Nd c #314c69",
"aB c #3156c2",
"kj c #3170cf",
"f1 c #3173e2",
"iD c #317ae1",
"ON c #323537",
"tv c #323a43",
"IN c #324a8e",
"xg c #324b8e",
"GC c #324b8f",
"#d c #3260d6",
"qH c #327bd4",
"oP c #3283e4",
"qk c #333333",
"GH c #334c8f",
"HL c #334d90",
"v2 c #33679f",
"Ne c #3368a2",
"bt c #3375eb",
"BL c #343434",
"GD c #344c90",
"xd c #344d90",
"dT c #345cb5",
"fn c #345eb1",
"QC c #347bc9",
"jD c #3480ec",
"f6 c #3482fe",
"w7 c #353534",
"GW c #353535",
"Oz c #353943",
"Cx c #354860",
"xf c #354f91",
"lD c #3569b3",
"ev c #357ae5",
"hp c #357fec",
"cX c #3582fd",
"eh c #3583ff",
"Cj c #363634",
"H3 c #363636",
"sF c #363f47",
"IC c #364d91",
"xe c #364e91",
"GE c #364f91",
"tA c #3654a1",
"xz c #374047",
"GG c #374f91",
"GF c #374f92",
"ej c #377aea",
"QB c #377ecc",
"rw c #3784e4",
"ni c #383838",
"L. c #383f45",
"Ko c #384361",
"HK c #385092",
"#j c #3858bb",
"pG c #388df1",
"yl c #393938",
"bu c #3955a6",
"eU c #3969ca",
"QG c #397bbe",
"QA c #3980cd",
"vf c #3a4044",
"HB c #3a5293",
"Do c #3a5da7",
"Cq c #3a6999",
"Hm c #3b392a",
"ys c #3b3a39",
"tr c #3b3b3b",
"pB c #3b3b3e",
"HJ c #3b5294",
".R c #3b52bb",
"y# c #3b5394",
".S c #3b61c9",
"nf c #3b8aef",
"Pp c #3c3c3c",
"G0 c #3c3c3f",
"Dw c #3c454d",
"F# c #3c464b",
"ve c #3c4754",
"HC c #3c5494",
"HI c #3c5595",
"#O c #3c60c8",
"Qz c #3c82ce",
"H4 c #3d3d3d",
"Fp c #3d4048",
"MB c #3d464d",
"oO c #3d4856",
"y. c #3d5496",
"IM c #3d5595",
"fq c #3d7bea",
"Qy c #3d84cf",
"Pb c #3e4148",
"Cn c #3e454c",
"zl c #3e5495",
"HD c #3e5595",
"je c #3e64ac",
"ft c #3e64b9",
"d. c #3e8dff",
"oJ c #3f3f3f",
"Is c #3f464c",
"K8 c #3f464e",
"#u c #3f55ac",
"HH c #3f5797",
"#p c #3f60ca",
"es c #3f6acc",
".w c #3f72d6",
"Qx c #3f86d1",
"QD c #3f8ad3",
"oh c #40404e",
"PP c #404651",
"yf c #405797",
"bd c #4059ab",
"d7 c #4069be",
"Qw c #4087d1",
"j0 c #408cff",
"Qr c #41403f",
"Hd c #414141",
"HE c #415798",
"HF c #415997",
"HG c #415998",
"Mc c #424242",
"IL c #425898",
"Qv c #4288d2",
"Dv c #43403f",
"x5 c #434342",
"Jz c #434f70",
"Ld c #435177",
"ye c #435a99",
"hD c #4376cc",
"m. c #4391f7",
"tj c #4396fe",
"uR c #44505d",
"mE c #44515c",
"ID c #445b9a",
"ci c #4464c5",
"Qu c #448bd4",
"jd c #448efd",
"Ir c #454d55",
".3 c #4555b2",
"Kz c #455b99",
"ya c #455b9a",
"IK c #455c9a",
"z0 c #456cba",
"Dy c #456f9e",
"Ge c #45719d",
"fV c #458eff",
".. c #4590dc",
"QF c #4592d8",
"Qo c #463d10",
"uL c #464646",
"zD c #464653",
"JK c #465c9b",
"yb c #465d9a",
"yd c #465d9b",
"F5 c #4676ac",
"w4 c #467ab2",
"eL c #468dff",
"QE c #4691d7",
"Gg c #474440",
"yw c #474746",
"GO c #474747",
"Nn c #475065",
"yc c #475e9b",
"IJ c #475f9c",
"Bg c #477cb4",
"Gp c #483e27",
"Kg c #484847",
"Oc c #484848",
"N8 c #48505b",
"JA c #485f9a",
"IE c #485f9d",
"gB c #4890ff",
"G1 c #49494d",
"qb c #495056",
"Ga c #4975aa",
"DH c #4978aa",
"iW c #4982dc",
"nS c #4989df",
"ic c #498bec",
"gQ c #498cf1",
"fx c #4991f4",
"dR c #4992ff",
"Dz c #4a4644",
"O. c #4a4f52",
"II c #4a609d",
"a. c #4a63bf",
"d4 c #4a68bd",
".1 c #4a7ade",
"km c #4a7dc8",
"F4 c #4a7fb5",
"Cy c #4a7fb7",
"xZ c #4a80b6",
"EP c #4b443d",
"r9 c #4b4b4b",
"IF c #4b609d",
"IH c #4b619d",
"JJ c #4b619f",
"zf c #4b629d",
"ze c #4b639e",
"b0 c #4b64b0",
"cd c #4b6cc8",
"Gd c #4b729c",
"y7 c #4b7fb7",
"Ae c #4b81b8",
"lA c #4b95ff",
"I2 c #4c4c4c",
"NO c #4c4c4d",
"IG c #4c639d",
"Ci c #4c6683",
"mO c #4c83cc",
"dy c #4c92ff",
"nl c #4d4d4c",
"pA c #4d4d4d",
"lQ c #4d575f",
"Aw c #4d639e",
"iL c #4d668e",
"dl c #4d93fc",
"ER c #4e493e",
"om c #4e4e4e",
"Q7 c #4e4f4e",
".c c #4e59b8",
"JI c #4e649f",
"A6 c #4e75bd",
"G# c #4e7aad",
"gI c #4e7bd0",
"e0 c #4e95ff",
"mD c #4f4e4c",
"CZ c #4f4f4f",
"za c #4f5051",
"zk c #4f65a0",
"h8 c #4f94ff",
"FO c #50504e",
"vb c #505050",
"wG c #505559",
"Ky c #5066a0",
"F6 c #507aac",
".I c #5087eb",
"kQ c #5096f1",
"fk c #5097ff",
"wv c #515151",
"LY c #51515f",
"JH c #5167a1",
"JB c #5167a2",
"JC c #5168a2",
"gT c #5178bf",
"yF c #517ac4",
"Gb c #517fb2",
"lb c #5197fa",
"wA c #525252",
"zs c #52525c",
"vi c #526eac",
"wt c #5277a3",
"G. c #527eae",
"F3 c #5281b2",
"ip c #5297f3",
"cK c #5298ff",
"DB c #535455",
"x6 c #535c62",
"MV c #53628b",
"JG c #5369a3",
"fw c #5379c2",
"F7 c #537eaf",
"F2 c #537fb1",
"nm c #545453",
"zE c #545465",
"zj c #5469a2",
"JD c #5469a3",
"JF c #546aa3",
"qh c #547aaa",
"F8 c #547fb1",
"dS c #5497f6",
"iz c #5497ff",
"ex c #5499ff",
"K7 c #555554",
"AN c #555555",
"IR c #555d62",
"It c #555e66",
"BC c #556373",
"JE c #556aa3",
"Kx c #556aa4",
"zg c #556ba4",
"jp c #556f94",
"xH c #557bc6",
"F9 c #557fb2",
"kO c #5599ff",
"wx c #565656",
"#K c #5663aa",
"gU c #569bfd",
"kP c #569bff",
"qw c #569ef7",
"EL c #575656",
"Jm c #575757",
"G2 c #57575b",
"Mz c #576a7b",
"zh c #576ca4",
"zi c #576da5",
"Kw c #576ea5",
"d8 c #5798f8",
"fA c #579bff",
"N9 c #585e60",
"Nu c #58668b",
"Lo c #586ea5",
"B7 c #5878b9",
"F1 c #5881a9",
"Gc c #5884af",
"C0 c #595958",
"Kp c #596ea7",
"fm c #5999f7",
"mp c #599bff",
"yv c #5a5a59",
"Fe c #5a5a5a",
"qo c #5a5a6c",
"tW c #5a6677",
"aY c #5a6aae",
"Kv c #5a6fa7",
"b5 c #5a72c8",
"cE c #5a73c2",
"lZ c #5a7daf",
"zK c #5b5b5b",
"mq c #5b9bff",
"uQ c #5c5c5c",
"oi c #5c5d6d",
"Bc c #5c6369",
"N6 c #5c6989",
"MM c #5c698a",
"Ap c #5c71a8",
"Ao c #5c72a8",
"Kq c #5c72a9",
"rX c #5c83ad",
"vD c #5c84af",
"nb c #5c9eff",
"gP c #5ca0ff",
"gJ c #5ca2ff",
"B. c #5d5b59",
"ns c #5d5d5d",
"SV c #5d5e5d",
"Pn c #5d6366",
"Ku c #5d72a8",
"Kr c #5d73a9",
"c6 c #5d74c8",
"sO c #5d83ad",
"tJ c #5d84ad",
"lW c #5d9eff",
"hI c #5d9fff",
"mZ c #5da6ff",
"Ic c #5e5802",
"LS c #5e5c5a",
"Sb c #5e5e61",
"Rd c #5e6265",
"IB c #5e6e93",
"Bz c #5e71a9",
"Ln c #5e72a9",
"M# c #5e73ae",
"b6 c #5e7fd3",
"uI c #5e85ad",
"nI c #5e9ee9",
"xy c #5f5d5c",
"qU c #5f5f5f",
"Kk c #5f6365",
"A9 c #5f6f81",
"ng c #5f708c",
"Av c #5f74aa",
"jX c #5f9fff",
"dx c #5fa1fb",
"zz c #606060",
".n c #6066a5",
"Kt c #6074aa",
"Ks c #6075ab",
"cc c #6083d6",
"gX c #60a0ff",
"r0 c #616160",
"sD c #616161",
"Q8 c #61656c",
".t c #616cc0",
"Fz c #617cb5",
"cI c #617dc4",
"mY c #618ac2",
"d9 c #61a3ff",
"NA c #626262",
"Lm c #6277ab",
"tV c #6282a8",
"q5 c #6285ad",
"xG c #6289ca",
"#6 c #6291ec",
"ug c #635c55",
"Q5 c #635e49",
"qu c #635f5d",
"Io c #636363",
"yB c #637280",
"M. c #6377ac",
"iM c #639ae0",
"fj c #63a1ff",
"hB c #63a2ff",
"q. c #646464",
"oj c #646673",
"xs c #646c75",
"dt c #6477bc",
"ek c #6478ab",
"Au c #6479ac",
"e. c #64a0ff",
"iU c #64a3ff",
"ht c #64a6fe",
"oa c #64a9fe",
"vL c #656565",
"z6 c #656668",
"zF c #656775",
"k3 c #65717f",
"Aq c #6579ae",
"dQ c #65a1ff",
"jb c #65a2ff",
"Ll c #667aae",
"px c #6682a8",
"a# c #668bda",
"yN c #6694dc",
"bI c #66a0f4",
"lB c #66a2ff",
"mb c #66a4ff",
"hu c #66a6ff",
"s0 c #66adff",
"rJ c #676767",
"io c #678bca",
"gc c #67a4ff",
"hm c #67a5ff",
"gb c #67a6ff",
"Ct c #686868",
"Cw c #68696b",
"Bn c #686d70",
"yS c #687178",
"vQ c #68727d",
"AV c #687885",
"At c #687caf",
"f7 c #687fb5",
"s3 c #6884a3",
"ux c #688cc6",
"xI c #6891ce",
"ie c #68a5ff",
"nQ c #696866",
"GY c #696969",
"RW c #69696a",
"xt c #696e75",
"cv c #6978ad",
"Ar c #697caf",
"Lk c #697cb0",
"Lf c #697db0",
"in c #6981ad",
".x c #6997ed",
"jH c #69a7ff",
"i0 c #69a8fe",
"gE c #69a9fe",
"fs c #69aaff",
"Nz c #6a6a6a",
"Ak c #6a7176",
"xm c #6a747b",
"As c #6a7cb0",
"en c #6a7cbc",
"ce c #6a7cc4",
"Lj c #6a7db1",
"Lg c #6a7eb1",
"Le c #6a7fb5",
"s4 c #6a849e",
"u8 c #6aa7ff",
"i1 c #6aa8ff",
"jE c #6aa9ff",
"sa c #6aafff",
"DC c #6b6861",
"Nc c #6b6a69",
"M0 c #6b6b6b",
"Jk c #6b6d72",
"Li c #6b7db1",
"Br c #6b7eb2",
"xW c #6b87a9",
"#k c #6b8dd3",
"ll c #6ba7ff",
"eM c #6ba8ff",
"il c #6babff",
"yz c #6c6b6b",
"sQ c #6c6c6c",
"pC c #6c6c6f",
"Rn c #6c6f71",
"FL c #6c7c8e",
"Lh c #6c7eb0",
"L9 c #6c7fb1",
"kR c #6c81a6",
"kb c #6c839f",
"xj c #6c89bd",
"jy c #6ca7ff",
"rk c #6caefb",
"lC c #6caefe",
"qg c #6cb2ff",
"ji c #6d6d6d",
"yn c #6d6d6e",
"jB c #6d84ac",
"s5 c #6d86a0",
"ws c #6d9cc7",
"Du c #6e6d6c",
"lG c #6e6e6e",
"Aa c #6e7983",
"Bs c #6e7fb1",
"L3 c #6e80b0",
"CL c #6e80b2",
"Gz c #6e84b5",
"tF c #6e92d0",
"jc c #6eabff",
"i. c #6eadfe",
"lF c #6f6f6f",
"Ke c #6f6f72",
"jq c #6f99cf",
"eY c #6fadfc",
"tM c #707070",
"By c #7082b3",
"L8 c #7083b4",
"kq c #70aaff",
"l# c #70abff",
"iN c #70adfe",
"ko c #70adff",
"FT c #71706f",
"pi c #717171",
"ay c #717db5",
"cy c #717fca",
"MU c #7185b9",
"v0 c #71a9ff",
"I3 c #727272",
"Cu c #727373",
"#N c #727bb8",
"L7 c #7285b6",
"Hz c #728bbd",
"wh c #7293c8",
"Cz c #72a8e1",
"R7 c #737271",
"Bl c #737373",
"Rb c #73767f",
"R. c #737780",
"R# c #737880",
"Ra c #737881",
"xX c #73a1e5",
"o4 c #73acff",
"fz c #73aeff",
"hC c #73b3ff",
"oN c #747270",
"j3 c #747474",
"NN c #747679",
"qp c #747785",
"Q9 c #747881",
"c1 c #7483c8",
"L6 c #7486b6",
"L4 c #7487b8",
"bz c #748dd8",
"bB c #748ed9",
"w1 c #74afff",
"gC c #74b0ff",
"ct c #74b2ff",
"im c #74b3ff",
"L# c #757372",
"RJ c #757575",
"V9 c #757781",
"t2 c #75828e",
"Bx c #7587b7",
"eQ c #758ccf",
".9 c #7591d8",
"#v c #7592d6",
".H c #75a5f2",
"f5 c #75aeff",
"vM c #767676",
"Rc c #767982",
"SU c #767a80",
"xP c #767e84",
"L5 c #7688b7",
"MT c #7688b8",
"Bt c #7689b7",
"nu c #768ba0",
"bA c #768fda",
"s2 c #7698bf",
"ik c #76afff",
"la c #76b1ff",
"iO c #76b2ff",
"v1 c #76bdff",
"Or c #777168",
"q9 c #777777",
"PM c #777879",
"xS c #777a7e",
"xQ c #777b7f",
"Qf c #777b88",
"dp c #778dd1",
"is c #77b0ff",
"ro c #77b1ff",
"ei c #77b3ff",
"oG c #77b6fa",
"FW c #786939",
"kT c #787878",
"ST c #787a7f",
"TY c #787b88",
"OJ c #7888b4",
"bC c #788dd5",
"s6 c #7892ae",
"b7 c #7897e2",
"m2 c #78b1ff",
"w3 c #78bdff",
"Dx c #78beff",
"AC c #797978",
"rh c #797979",
"Ii c #79797a",
"TH c #797a7b",
"UA c #797a81",
"xR c #797c7e",
"hq c #7988a9",
"Bw c #798bba",
"u# c #79b2ff",
"n9 c #79b3ff",
"eN c #79b4fd",
"jA c #79b8ff",
"xY c #79bcff",
"RV c #7a7978",
"lf c #7a7a7a",
"RU c #7a7a7b",
"jo c #7a8188",
"#i c #7a85cd",
"Bu c #7a8bb9",
"CD c #7a8bba",
"pm c #7a8fa4",
"hs c #7a93c8",
"yh c #7a95c4",
"kn c #7ab0ff",
"y6 c #7abdff",
"DD c #7b756b",
"NP c #7b7b7b",
"xT c #7b7e81",
".Q c #7b81c9",
"Bv c #7b8dba",
"Eq c #7b99cc",
".T c #7b9fe2",
"ud c #7bb0ff",
"ey c #7bb1ff",
"kh c #7bb2ff",
"sq c #7bb3ff",
"eZ c #7bb5ff",
"g# c #7bb6ff",
"Ad c #7bbfff",
"Hc c #7c7b7b",
"EI c #7c7c7c",
"RK c #7c7d7d",
"On c #7c7e81",
"NM c #7c7e82",
"Vt c #7c7f87",
"xU c #7c8287",
".7 c #7c83c9",
"AA c #7c92a8",
"eu c #7c95d3",
"cb c #7c9fe7",
"xF c #7ca5d8",
"nc c #7cb0ff",
"o1 c #7cb4ff",
"nT c #7cb6fe",
"Oo c #7d7975",
"Cm c #7d7b78",
"JO c #7d7d7d",
"Cs c #7d7d7e",
"Qe c #7d7e88",
"R6 c #7d7f84",
".M c #7d83c2",
"xV c #7d8891",
"MS c #7d8fbc",
"jW c #7db3ff",
"pQ c #7db4ff",
"hH c #7db6fe",
"oY c #7db6ff",
"id c #7db8ff",
"Bf c #7dc1ff",
"LJ c #7e7c7a",
"Kn c #7e7e7c",
"nK c #7e7e7e",
"RL c #7e8082",
"SS c #7e8085",
"OZ c #7e8187",
"uZ c #7e8c98",
"DU c #7e8dbb",
"Nt c #7e90bf",
"cz c #7e94d7",
"wV c #7ea3cd",
"gY c #7eb4ff",
"nW c #7eb5ff",
"sm c #7eb6ff",
"lg c #7f7f7f",
"DA c #7f7f80",
"GR c #7f7f8d",
"TX c #7f8390",
"vg c #7f8b92",
"CE c #7f8fbc",
"MR c #7f90bc",
"vZ c #7fb7ff",
"ew c #7fb9ff",
"o7 c #7fbcff",
"TI c #807970",
"pE c #807e7b",
"sP c #808080",
"NL c #808386",
"y1 c #808387",
"yk c #808e97",
"by c #808fd3",
"MO c #8090bd",
"dW c #8091d0",
"ds c #80a0e4",
"xJ c #80abe2",
".y c #80adf5",
"kg c #80b5ff",
"fU c #80b6ff",
"o0 c #80b7ff",
"Sm c #817c7a",
"Ot c #817f7d",
"Kd c #818082",
"LX c #818090",
"l1 c #818181",
"yT c #818283",
"RT c #818489",
"fZ c #818eac",
"CK c #8191bd",
"MQ c #8192bd",
"MP c #8192be",
"MN c #8194c1",
"wU c #81a3ce",
"Cf c #81a8df",
".G c #81b1f8",
"pR c #81b5ff",
"tg c #81b6ff",
"pK c #81b7ff",
"ga c #81b8ff",
"pw c #81bfff",
"EJ c #828282",
"Kc c #82838a",
"Jt c #82868a",
".b c #828acc",
"lX c #82b5ff",
"h7 c #82b6ff",
"f2 c #82b7ff",
"iA c #82b8ff",
"fy c #82baff",
"u9 c #82c5ff",
"O6 c #837864",
"le c #838383",
"Cv c #838487",
"R5 c #838589",
"t1 c #83868a",
"Sl c #83878e",
"oX c #83b9ff",
"gV c #83bbff",
"ue c #83c5ff",
"Ud c #848487",
"Sa c #848586",
"Vr c #848589",
"SC c #84868f",
"S7 c #84888f",
"z5 c #84919a",
"Jq c #8495a1",
"Ds c #849ab2",
"zm c #849dc9",
"m1 c #84b7ff",
"lm c #84b8ff",
"Op c #857d72",
"kU c #858585",
"mX c #858686",
"Rl c #858688",
"TG c #85888e",
"Iu c #8593a0",
"Ns c #8596c0",
"En c #8597a6",
"cD c #85a4e8",
"aC c #85a9e3",
"sr c #85baff",
"gW c #85bbff",
"TL c #867d70",
"lP c #868583",
"H9 c #868680",
"zw c #868686",
"LT c #86939c",
"Pk c #8694bf",
"LU c #8696a3",
"oH c #8696ab",
".0 c #86b2f3",
"s1 c #86b4ed",
"bh c #86b4f6",
"t7 c #86baff",
"t6 c #86bbff",
"fW c #86bcff",
"jF c #86bdff",
"lk c #86bfff",
"Aj c #878685",
"nL c #878787",
"Rm c #878889",
"tX c #87898b",
"OI c #8796c0",
"N5 c #8797c3",
"#c c #87b0f3",
"oS c #87bbff",
"kp c #87bcff",
"jZ c #87bdff",
"bY c #87bfff",
"TM c #88775a",
"Oq c #888176",
"Ue c #88857f",
"S# c #888888",
"SR c #888a8e",
"PB c #888c98",
"b4 c #8892d1",
"CJ c #8897c1",
"Nr c #8898c3",
"sI c #88a9dc",
"eR c #88b3f2",
"MA c #88b6dd",
"dj c #88b9ff",
"jz c #88bdff",
"ho c #88beff",
"fX c #88bfff",
"O0 c #897c69",
"V7 c #89837d",
"LI c #89847a",
"wC c #898989",
"vv c #898f92",
"wl c #89949b",
"vA c #8998a6",
"CF c #8999c2",
"pN c #89bcff",
"ir c #89bdff",
"Tp c #8a8885",
"zy c #8a8a8a",
"Uy c #8a8b91",
"Om c #8a8d92",
"Iv c #8a8f94",
"iE c #8a95ac",
"DM c #8a9ac2",
"Nq c #8a9ac3",
"PZ c #8a9fcd",
"FK c #8aacde",
"vW c #8abeff",
"iq c #8abfff",
"m# c #8ac1ff",
"RX c #8b8782",
"I1 c #8b8b8a",
"jj c #8b8b8b",
"Ai c #8b8c8c",
"RI c #8b8c8d",
"Jy c #8b8c8f",
"S6 c #8b8f96",
"N4 c #8b9ac2",
"Np c #8b9bc4",
"Ma c #8b9fba",
"qE c #8bbdff",
"oZ c #8bbeff",
"hK c #8bc0ff",
"TJ c #8c806e",
"SD c #8c8682",
"l6 c #8c8c8c",
"Vs c #8c8d8f",
"GS c #8c8d99",
"KY c #8c8e8f",
"NK c #8c8e90",
"ka c #8c8e91",
"CI c #8c9bc4",
"c8 c #8c9fd4",
"#o c #8cacf1",
"b8 c #8caded",
"o2 c #8cbeff",
"ua c #8cbfff",
"cW c #8cc0ff",
"Cp c #8cd0ff",
"Bm c #8d8c8c",
"OY c #8d8d8c",
"mR c #8d8d8d",
"OX c #8d8f94",
"V8 c #8d9097",
"NX c #8d9abd",
"CG c #8d9cc4",
"te c #8dbeff",
"jG c #8dc0ff",
"fl c #8dc2ff",
"q4 c #8dc6ff",
"SF c #8e8b85",
"My c #8e8c8a",
"Ec c #8e8e8d",
"lK c #8e8e8e",
"BE c #8e8e8f",
"H8 c #8e8e90",
"Ji c #8e9090",
"CH c #8e9dc5",
"jC c #8ea6cd",
"jI c #8ebfff",
"h9 c #8ec0ff",
"oQ c #8ec1ff",
"iC c #8ec2ff",
"iV c #8ec5ff",
"pU c #8ec7ff",
"UB c #8f7c60",
"yx c #8f8f8e",
"G4 c #8f8f8f",
"Jj c #8f9091",
"PA c #8f929a",
"cF c #8f94be",
"OH c #8f9ec5",
"P2 c #8fa1af",
"Ax c #8fa6ce",
"ca c #8fb2ef",
"aw c #8fbbf6",
"e1 c #8fbfff",
"u6 c #8fc0ff",
"rU c #8fc1ff",
"gD c #8fc3ff",
"Nb c #908f8e",
"RH c #90908f",
"jh c #909090",
"R4 c #909294",
"wr c #909395",
"Kb c #90949c",
"cZ c #9099b3",
"N3 c #909ec6",
"y2 c #909fa7",
"zb c #909fab",
"DN c #909fc6",
"c2 c #90a4db",
"v6 c #90a5ba",
"GL c #90afdd",
"rt c #90bfff",
"qe c #90c0ff",
"gz c #90c3ff",
"wF c #918f8e",
"pY c #919191",
"GQ c #9191a0",
"Uz c #919394",
"RS c #919397",
".o c #9195bd",
"bD c #9197d5",
"E8 c #91a4d1",
"sJ c #91b4e1",
"w2 c #91beff",
"t8 c #91c0ff",
"it c #91c2ff",
"iB c #91c3ff",
"ki c #91c7ff",
"PK c #927732",
"nn c #929291",
"mQ c #929292",
"SQ c #929393",
"OA c #929ebd",
"DT c #92a0c7",
"No c #92a3ce",
"u0 c #92b7de",
"a2 c #92b7ec",
"mM c #92c0ff",
"qA c #92c1ff",
"hn c #92c3ff",
"z# c #939293",
"Ih c #939392",
"w6 c #939393",
"zt c #93969d",
"PR c #93a1bb",
"t3 c #93adc5",
"hJ c #93c3ff",
"hk c #93c4ff",
"S8 c #947e52",
"Ws c #94834b",
"WT c #949076",
"z. c #949494",
"zr c #94949f",
"uY c #949596",
"Ro c #949699",
"#f c #9497c0",
"lc c #94a0b3",
"Pj c #94a0c6",
"N2 c #94a2c8",
"fp c #94a4d8",
"HQ c #94a5b0",
"HN c #94b4df",
"oC c #94c1ff",
"fB c #94c3ff",
"nU c #94c4ff",
"eK c #94c5ff",
"st c #94c6ff",
"CA c #94c7f7",
"Qg c #95824c",
"RG c #959494",
"mv c #959595",
"SB c #959598",
"KX c #959697",
"OG c #95a3c8",
"dX c #95b0e6",
".z c #95befa",
"d# c #95c0ff",
"ny c #95c3ff",
"ox c #95c4ff",
"sn c #95c5ff",
"gd c #95c6ff",
"PC c #968356",
"KZ c #96876c",
"yr c #969594",
"uj c #969696",
"A# c #969697",
"Rf c #969797",
"Eb c #96979b",
"jn c #96989c",
"LZ c #969aa4",
"gR c #969fb7",
"N1 c #96a4c9",
"xO c #96abbc",
"s7 c #96b5d4",
".F c #96c1fc",
"sp c #96c4ff",
"i2 c #96c5ff",
"fT c #96c6ff",
"ne c #96c7ff",
"Hl c #979047",
"WK c #979383",
"Bb c #979594",
"Ah c #979797",
".4 c #9799bf",
"Sk c #979aa2",
"N0 c #97a4cb",
"NZ c #97a5ca",
"PY c #97aad4",
"BA c #97add2",
"Bd c #97b6d1",
"#I c #97bcf3",
"jr c #97c5fb",
"oB c #97c5ff",
"hl c #97c6ff",
"gA c #97c7ff",
"lY c #97ccff",
"Fo c #988a6b",
"MK c #989897",
"Bk c #989898",
"PQ c #98a7c3",
"vT c #98c5ff",
"kN c #98c6ff",
"i3 c #98c7ff",
"h5 c #98c8ff",
"TK c #998a77",
"x4 c #999999",
"qn c #9999af",
"vz c #999ea4",
"Bo c #99aebb",
"xL c #99c5ff",
"yP c #99c6ff",
"iu c #99c7ff",
"na c #99c8ff",
"pH c #99c9ff",
"EX c #99d4ff",
"WJ c #9a8f45",
"Sj c #9a9798",
"Jc c #9a9991",
"lJ c #9a9a9a",
"Pc c #9aa2b8",
"EW c #9aa6b3",
"DS c #9aa7cb",
"OF c #9aa8cc",
"Js c #9aacba",
"E0 c #9aaed8",
"IO c #9ab8e1",
"vV c #9ac6ff",
"eg c #9ac7ff",
"jJ c #9ac8ff",
"ks c #9ac9ff",
"jY c #9acaff",
"U1 c #9b8d44",
"WS c #9b9143",
"Rt c #9b9962",
"k2 c #9b9998",
"Rs c #9b9b61",
"NJ c #9b9b9a",
"oI c #9b9b9b",
"t0 c #9b9c9d",
"DO c #9ba8cc",
"vR c #9bb5cc",
"o5 c #9bc3ff",
"rV c #9bc6ff",
"xM c #9bc7ff",
"kr c #9bc8ff",
"h6 c #9bc9ff",
"S5 c #9c8861",
"Ea c #9c9187",
"UQ c #9c9682",
"Qq c #9c9b9b",
"Na c #9c9c9b",
"Bj c #9c9c9c",
"og c #9c9ca5",
"Ol c #9c9d9c",
"y0 c #9c9da1",
"Iz c #9c9e9e",
"Pi c #9ca7ca",
"l9 c #9cb0d0",
"oy c #9cc8ff",
"ma c #9cc9ff",
"o# c #9ccaff",
"oR c #9ccbff",
"SE c #9d958c",
"VI c #9d995e",
"Ru c #9d9978",
"Rr c #9d9b64",
"Rk c #9d9d9c",
"mC c #9d9d9d",
"R3 c #9d9e9f",
"NY c #9dabd2",
"OE c #9dacce",
"wH c #9db9ce",
"u5 c #9dc7ff",
"n3 c #9dc9ff",
"n4 c #9dcaff",
"iy c #9dcbff",
"o. c #9dccff",
"mN c #9dd0ff",
"RA c #9e9b71",
"tY c #9e9d9d",
"Ba c #9e9e9e",
"Iw c #9e9e9f",
"vw c #9ea0a2",
"wW c #9eb8d0",
"EE c #9ec0ee",
"u2 c #9ec7ff",
"rr c #9ec8ff",
"rp c #9ec9ff",
"nz c #9ecaff",
"rq c #9ecbff",
"j# c #9eccff",
"qG c #9ed0ff",
"Cr c #9f9a98",
"VP c #9f9b65",
"VQ c #9f9c7e",
"RB c #9f9c82",
"kY c #9f9f9f",
"#8 c #9fa3c0",
"vu c #9facba",
"DR c #9facce",
"PX c #9fb2d8",
"JL c #9fbbe3",
"b9 c #9fbef3",
"sG c #9fc2e7",
".A c #9fc7fe",
"qF c #9fc7ff",
"q1 c #9fc8ff",
"u4 c #9fcaff",
"fi c #9fcbff",
"ms c #9fccff",
"qx c #9fcdff",
"Vu c #a0803a",
"Sn c #a09079",
"Rz c #a09d71",
"VO c #a09e5b",
"VH c #a0a052",
"p9 c #a0a09f",
"jk c #a0a0a0",
"N# c #a0a1a1",
"SA c #a0a3ad",
"DP c #a0adce",
"Ab c #a0c0dd",
"td c #a0c9ff",
"q0 c #a0ccff",
"sb c #a0ceff",
"nG c #a0cfff",
"OW c #a1937f",
"If c #a19d90",
"pc c #a19f6b",
"AR c #a19f6d",
"vP c #a19f9d",
"VN c #a1a064",
"La c #a1a1a0",
"x3 c #a1a1a1",
"do c #a1a9d6",
"DQ c #a1aece",
"OD c #a1aecf",
"rL c #a1b4c4",
"CM c #a1b5d7",
"c# c #a1c0f4",
"kc c #a1c4e8",
"q2 c #a1caff",
"u. c #a1cbff",
"hL c #a1ccff",
"wQ c #a1cdff",
"bs c #a1ceff",
"jU c #a1cfff",
"sc c #a1d1ff",
"SW c #a28749",
"VJ c #a29e86",
"iJ c #a2a2a1",
"mz c #a2a2a2",
"bx c #a2a5d8",
"Ph c #a2adcd",
"OC c #a2afd0",
"c5 c #a2b7ee",
"eo c #a2c1ef",
"n2 c #a2ccff",
"ln c #a2cdff",
"kf c #a2ceff",
"kt c #a2cfff",
"Rq c #a3a07c",
"Ry c #a3a182",
"yU c #a3a2a0",
"Jh c #a3a3a2",
"kZ c #a3a3a3",
"TD c #a3a4a6",
"#r c #a3a8ce",
"IA c #a3a9a9",
"vU c #a3cbff",
"xC c #a3ccff",
"n6 c #a3cdff",
"md c #a3ceff",
"j. c #a3cfff",
"o6 c #a3d0ff",
"rv c #a3d1ff",
"Ux c #a49175",
"VG c #a4952b",
"WC c #a49944",
"tZ c #a4a3a2",
"jm c #a4a4a4",
"Hr c #a4b3be",
"k4 c #a4c1db",
"wX c #a4c3dd",
"Ht c #a4c5e8",
"m9 c #a4ccff",
"ps c #a4cdff",
"mc c #a4ceff",
"jx c #a4cfff",
"ku c #a4d0ff",
"kL c #a4d1ff",
"QT c #a5942d",
"Mp c #a59961",
"WM c #a59a46",
"U9 c #a59d59",
"Ve c #a59d5b",
"WL c #a5a081",
"VM c #a5a27e",
"iK c #a5a4a2",
"nM c #a5a5a5",
"zG c #a5a7ad",
"TE c #a5a9af",
"c7 c #a5a9cd",
"E1 c #a5b6db",
"KA c #a5c0e4",
"vB c #a5c1db",
"c. c #a5c2f4",
"Co c #a5c3de",
".E c #a5ccff",
"t. c #a5cdff",
"mj c #a5ceff",
"ou c #a5cfff",
"A8 c #a5d0fd",
"lo c #a5d0ff",
"jT c #a5d1ff",
"nH c #a5d3ff",
"Wh c #a6915d",
"jl c #a6a6a6",
"DG c #a6a6ae",
"OB c #a6b4d5",
"E7 c #a6b7dd",
"yR c #a6baca",
"qC c #a6ceff",
"ja c #a6cfff",
"rn c #a6d0ff",
"jV c #a6d1ff",
"w0 c #a6d2ff",
"KW c #a79884",
"B3 c #a7a6a5",
"xn c #a7a6a6",
"iI c #a7a7a7",
"DX c #a7b4bd",
"PW c #a7b8dc",
"dP c #a7ccff",
"wI c #a7ceff",
"t# c #a7cfff",
"m0 c #a7d0ff",
"h4 c #a7d1ff",
"kM c #a7d3ff",
"l. c #a7d4ff",
"sd c #a7d7ff",
"tK c #a8a8a8",
"TF c #a8a8a9",
"eP c #a8adbd",
"Pg c #a8b2d1",
"wT c #a8c1d3",
"tw c #a8c4df",
"rs c #a8cdff",
"eI c #a8ceff",
"h. c #a8cfff",
"qB c #a8d0ff",
"sM c #a8d1ff",
"lp c #a8d2ff",
"jS c #a8d3ff",
"Q4 c #a99a2b",
"Ie c #a99b2d",
"WB c #a9a48d",
"QU c #a9a69d",
"oe c #a9a9a9",
"k0 c #a9a9aa",
"DV c #a9bddb",
"sH c #a9c8e9",
"zQ c #a9caf0",
"nV c #a9cfff",
"nx c #a9d0ff",
"oA c #a9d1ff",
"i4 c #a9d2ff",
"kv c #a9d3ff",
"oF c #a9d5ff",
"TC c #aaa69d",
"wq c #aaa9a8",
"l7 c #aaaaaa",
"Ok c #aaaaab",
"sX c #aaabab",
"Oi c #aaabae",
"Oj c #aaaeb2",
"uA c #aacbf1",
"qz c #aad0ff",
"aW c #aad1fd",
"iP c #aad2ff",
"kK c #aad3ff",
"nX c #aad4ff",
"sN c #aaddff",
"QW c #aba37d",
"Hg c #aba64b",
"Mx c #aba68d",
"uS c #abaaa8",
"Ka c #abaaab",
"xp c #ababab",
"PS c #abb9d6",
"Gv c #abc0cf",
"gK c #abcfff",
"fN c #abd0ff",
"i8 c #abd1ff",
"pT c #abd3ff",
"jR c #abd4ff",
"lq c #abd5ff",
"PJ c #ac9041",
"Va c #aca66e",
"Rv c #acaaa1",
"l2 c #acacac",
"SJ c #acadad",
"j2 c #acb1ba",
"Fx c #acc3d4",
"zN c #acc5d9",
"z3 c #acd1ff",
"tH c #acd2ff",
"rl c #acd3ff",
"pv c #acd4ff",
"lz c #acd5ff",
"Ch c #acd7ff",
"se c #acdcff",
"Wz c #ad9422",
"U5 c #ada651",
"RC c #adaba2",
"Iy c #adacad",
"Ag c #adadad",
"wm c #adaeaf",
"vy c #adb0b3",
"nJ c #adb2bc",
"Pf c #adb6d4",
"PV c #adbfdf",
"un c #adc1cd",
"pS c #adcfff",
"d3 c #add0fa",
"kB c #add2ff",
"n1 c #add3ff",
"mi c #add4ff",
"ly c #add5ff",
"kJ c #add6ff",
"Ty c #aea497",
"Wt c #aeaa9e",
"Sz c #aeaaab",
"Oh c #aeada9",
"va c #aeaeae",
"CY c #aeb0b4",
"op c #aecfed",
"fO c #aed1ff",
"ot c #aed3ff",
"lv c #aed4ff",
"iT c #aed5ff",
"tI c #aedfff",
"Pz c #af8f4a",
"v# c #afa8a2",
"Kf c #afaaa5",
"CT c #afaaa7",
"WA c #afaea9",
"Ix c #afaeae",
"y9 c #afafaf",
"zC c #afafb7",
"CX c #afb1b5",
"E6 c #afc0e2",
"Ki c #afc5d7",
"lR c #afcae2",
"zn c #afcdea",
"vr c #afcdef",
"gu c #afd2ff",
"h0 c #afd3ff",
"jN c #afd4ff",
"uz c #afd5ff",
"m3 c #afd6ff",
"lV c #afd7ff",
"mo c #afd8ff",
"WR c #b0a429",
"Vd c #b0ac3d",
"lO c #b0afaf",
"RR c #b0b0af",
"nr c #b0b0b0",
"BM c #b0b3b9",
"K# c #b0b3ba",
"Pe c #b0b9d5",
"Kj c #b0c6d6",
"w9 c #b0cbe5",
"tz c #b0ceec",
"ee c #b0d3ff",
"kE c #b0d4ff",
"rO c #b0d5ff",
"i9 c #b0d6ff",
"rm c #b0d7ff",
"kI c #b0d8ff",
"Vb c #b1ac43",
"tS c #b1b0b0",
"k1 c #b1b1b0",
"zJ c #b1b1b1",
"cf c #b1b2d2",
"vx c #b1b3b4",
".s c #b1b5de",
"CN c #b1bcc5",
".U c #b1cef8",
"ea c #b1d2ff",
"qd c #b1d3ff",
"fe c #b1d4ff",
"y3 c #b1d5f5",
"m7 c #b1d5ff",
"so c #b1d6ff",
"nF c #b1d7ff",
"k9 c #b1d8ff",
"lr c #b1d9ff",
"sf c #b1dcff",
"uH c #b1e2ff",
"Si c #b2a695",
"Rx c #b2b0a4",
"nk c #b2b2b0",
"ld c #b2b2b2",
"pD c #b2b2b3",
"f9 c #b2bcd2",
"E2 c #b2c3e3",
"uE c #b2d2ee",
"ef c #b2d3ff",
"g3 c #b2d5ff",
"xE c #b2d6f9",
"rT c #b2d7ff",
"mn c #b2d8ff",
"bb c #b2d9ff",
"t5 c #b2daff",
"T6 c #b3a990",
"Hf c #b3af9a",
"Jx c #b3b2b1",
"mV c #b3b3b3",
"GZ c #b3b3b4",
"#t c #b3b9de",
"e4 c #b3d4ff",
"v7 c #b3d5f5",
"eC c #b3d5ff",
"hb c #b3d6ff",
"pr c #b3d7ff",
"n5 c #b3d8ff",
"oT c #b3d9ff",
"qy c #b3daff",
"Wj c #b4a252",
"U8 c #b4af33",
"Hk c #b4b12e",
"CW c #b4b3b3",
"pb c #b4b490",
"oL c #b4b4b3",
"mU c #b4b4b4",
"K. c #b4b7bc",
"KB c #b4c1cb",
"OK c #b4cae3",
"Lp c #b4cef0",
"eD c #b4d6ff",
"i7 c #b4d7ff",
"uF c #b4d8f8",
"n0 c #b4d8ff",
"me c #b4daff",
"kH c #b4dbff",
"xK c #b4dcff",
"rM c #b4dfff",
"rW c #b4e2ff",
"TZ c #b5912c",
"Mw c #b5a72c",
"TB c #b5aca0",
"Vc c #b5b334",
"Rp c #b5b3a9",
"wp c #b5b4b3",
"MC c #b5b5b4",
"kX c #b5b5b5",
"yo c #b5b5b6",
"RQ c #b5b7ba",
"RP c #b5b9bc",
"qq c #b5bcc8",
"Pd c #b5bfd9",
"wS c #b5d1e9",
"EF c #b5d2e8",
"dB c #b5d6ff",
"hd c #b5d7ff",
"ha c #b5d8ff",
"hj c #b5d9ff",
"lx c #b5daff",
"ru c #b5dbff",
"vY c #b5ddff",
"WI c #b6a724",
"WN c #b6ac2a",
"VR c #b6b5ae",
"wE c #b6b5b5",
"FN c #b6b6b5",
"z8 c #b6b6b6",
"Ha c #b6b6b7",
"Nh c #b6b6ba",
"mu c #b6b9c1",
"PU c #b6c7e5",
"qY c #b6cee3",
".B c #b6d6ff",
"fM c #b6d7ff",
"g9 c #b6d8ff",
"kF c #b6d9ff",
"s8 c #b6dafa",
"jK c #b6daff",
"ti c #b6dbff",
"n# c #b6dcff",
"xD c #b6deff",
"sg c #b6dfff",
"QL c #b7a735",
"UT c #b7a740",
"Sq c #b7ad97",
"Og c #b7b2aa",
"U6 c #b7b530",
"Vf c #b7b5ab",
"H# c #b7b5b4",
"WW c #b7b6b1",
"AQ c #b7b798",
"xu c #b7b7b7",
"xo c #b7b7b8",
"R9 c #b7b8ba",
"Qp c #b7b8be",
"RO c #b7b9bc",
"Je c #b7babf",
"E5 c #b7c7e6",
"E3 c #b7c8e7",
"xA c #b7d5ec",
"pI c #b7d7ff",
".D c #b7d8ff",
"g7 c #b7d9ff",
"ij c #b7daff",
"y5 c #b7dbff",
"lU c #b7dcff",
"sh c #b7deff",
"vC c #b7e8ff",
"Vq c #b88b32",
"U7 c #b8b72b",
"I. c #b8b7b3",
"Ck c #b8b8b7",
"j4 c #b8b8b8",
"ym c #b8b8b9",
".C c #b8d7ff",
"gj c #b8d8ff",
"gp c #b8d9ff",
"lu c #b8daff",
"t4 c #b8dbf7",
"nC c #b8dbff",
"uc c #b8dcff",
"lw c #b8ddff",
"ub c #b8deff",
"So c #b9a98f",
"SG c #b9ad9d",
"Oe c #b9b5ae",
"WX c #b9b8b5",
"wo c #b9b9b8",
"mW c #b9b9b9",
"G3 c #b9babb",
"a0 c #b9bed5",
"bf c #b9c0d7",
"E4 c #b9c9e8",
"PT c #b9cae8",
"K9 c #b9cfe3",
"uB c #b9d2ee",
"up c #b9d4ec",
"eH c #b9d9ff",
"ge c #b9daff",
"sK c #b9dbf7",
"iv c #b9dbff",
"pp c #b9dcff",
"er c #b9ddff",
"mf c #b9deff",
"Mr c #bab391",
"J7 c #bab7b5",
"yZ c #bab8b6",
"Hh c #bab928",
"z9 c #bab9b8",
"l5 c #bababa",
"Lb c #bababb",
"R2 c #babbbb",
"Dd c #bad3ef",
"E9 c #bad3f3",
"w. c #bad4ef",
"fF c #bad9ff",
"hc c #badaff",
"cs c #badbff",
"nZ c #badcff",
"qD c #baddff",
"z1 c #badefd",
"n. c #badeff",
"pu c #badfff",
"Qd c #bb9829",
"Sw c #bbb4ad",
"A. c #bbbab8",
"vH c #bbbbbb",
"dn c #bbbeca",
"hf c #bbd8ff",
"hy c #bbd9ff",
"h# c #bbdaff",
"k6 c #bbdbff",
"wY c #bbdcfa",
"rN c #bbdcff",
"or c #bbddff",
"th c #bbdeff",
"m4 c #bbdfff",
"oE c #bbe0ff",
"O1 c #bca378",
"k# c #bcb9b7",
"VL c #bcbaad",
"NI c #bcbbbb",
"IT c #bcbcba",
"BS c #bcbcbb",
"yy c #bcbcbc",
"bE c #bcbcd5",
"f0 c #bcc5e0",
"Db c #bcc7cd",
"Hu c #bcd5ec",
"fb c #bcdaff",
"jw c #bcdbff",
"g8 c #bcdcff",
"jO c #bcddff",
"os c #bcdeff",
"mm c #bcdfff",
"u1 c #bce1ff",
"Ac c #bce3ff",
"To c #bd9d59",
"WD c #bdb324",
"US c #bdbab2",
"yV c #bdbbba",
"V. c #bdbcb3",
"uX c #bdbcbb",
"RN c #bdbcbd",
"l3 c #bdbdbd",
"Hj c #bdbf1f",
"ok c #bdbfc4",
"cA c #bdd0f2",
"he c #bdd8ff",
"ta c #bdd9ff",
"P0 c #bddaf7",
"g6 c #bddaff",
"oD c #bddbff",
"mr c #bddcff",
"mI c #bdddff",
"yE c #bddefe",
"jQ c #bddeff",
"mJ c #bddfff",
"kw c #bde0ff",
"u7 c #bde1ff",
"sL c #bde2ff",
"Tq c #be9c45",
"Mk c #beb130",
"Sy c #beb8b1",
"CV c #bebbb7",
"WV c #bebdb9",
"iH c #bebebe",
"Hb c #bebebf",
"Hi c #bebf1e",
"AJ c #bec1c9",
".a c #bec2e3",
"eG c #bedbff",
"ii c #bedcff",
"hT c #beddff",
"hA c #bedeff",
"po c #bedfff",
"ml c #bee0ff",
"si c #bee1ff",
"y4 c #bee4ff",
"Ms c #bfb32f",
"WQ c #bfb81e",
"U4 c #bfbba8",
"WZ c #bfbebc",
"J9 c #bfbec2",
"my c #bfbfbf",
"SP c #bfbfc0",
"J6 c #bfc1c4",
"cx c #bfc2e5",
"v8 c #bfdaf5",
"gL c #bfdbff",
"dO c #bfdcff",
".Z c #bfddff",
"nB c #bfdeff",
"gt c #bfdfff",
"n7 c #bfe0ff",
"mK c #bfe1ff",
"mL c #bfe2ff",
"DI c #bfe6ff",
"F0 c #c09e42",
"UP c #c0a717",
"Se c #c0b39d",
"TA c #c0b5a3",
"l4 c #c0c0c0",
"UR c #c0c0c1",
"et c #c0c1d0",
"tc c #c0dbff",
"gO c #c0dcff",
"gk c #c0deff",
"tf c #c0e0ff",
"ck c #c0e1ff",
"oU c #c0e2ff",
"yj c #c0e4ff",
"K0 c #c1ab84",
"WO c #c1bd1e",
"yu c #c1c1c0",
"x2 c #c1c1c1",
"R1 c #c1c3c6",
"Ja c #c1c5cb",
"dv c #c1c9de",
"uD c #c1dbf1",
"fC c #c1deff",
"fh c #c1dfff",
"fG c #c1e0ff",
"Hs c #c1e1fa",
"q3 c #c1e1ff",
"nY c #c1e2ff",
"s9 c #c1e3ff",
"W. c #c2991f",
"E# c #c2ae91",
"DF c #c2bebd",
"uV c #c2c1c1",
"lL c #c2c2c2",
".N c #c2c2d3",
"RY c #c2c4c8",
"MJ c #c2c4ca",
"p8 c #c2c5cb",
"B5 c #c2dcf2",
"g5 c #c2dcff",
"dK c #c2ddff",
"ix c #c2dfff",
"hM c #c2e0ff",
"mF c #c2e1f8",
"pq c #c2e1ff",
"ls c #c2e2ff",
"nE c #c2e3ff",
"qf c #c2e4ff",
"uG c #c2e5ff",
"Be c #c2e7ff",
"Sr c #c3b79f",
"BV c #c3c3ba",
"j7 c #c3c3c3",
"NH c #c3c3c4",
"SO c #c3c5c8",
"SN c #c3c5c9",
"#P c #c3d6f5",
"AW c #c3dff5",
"e5 c #c3dfff",
"hN c #c3e0ff",
"fS c #c3e1ff",
"o3 c #c3e2ff",
"m5 c #c3e3ff",
"n8 c #c3e4ff",
"oq c #c3e5ff",
"M5 c #c4c4b5",
"l0 c #c4c4c4",
"H7 c #c4c4cb",
"iX c #c4c6cd",
"r8 c #c4c9ce",
"Lq c #c4d3d6",
"xa c #c4d4e9",
"Pl c #c4d8ef",
"Al c #c4daec",
"#. c #c4daf7",
"cC c #c4dafc",
"hz c #c4ddff",
"gi c #c4dfff",
"nd c #c4e0ff",
"iw c #c4e1ff",
"fL c #c4e2ff",
"js c #c4e3ff",
"nw c #c4e4ff",
"qZ c #c4e5ff",
"x. c #c4e7ff",
"PI c #c5a74d",
"Wu c #c5ab27",
"QX c #c5b41e",
"Gh c #c5b685",
"DE c #c5beb3",
"Af c #c5beb8",
"v3 c #c5beb9",
"WP c #c5c119",
"M6 c #c5c4b8",
"W0 c #c5c4c3",
"p1 c #c5c5aa",
"uP c #c5c5c5",
"SM c #c5c8cc",
"BK c #c5c8ce",
"Nm c #c5c8cf",
"B2 c #c5c9d0",
"hF c #c5cbd7",
"uC c #c5dcf1",
"da c #c5dfff",
"di c #c5e0ff",
"fD c #c5e1ff",
"gZ c #c5e2ff",
"oV c #c5e3ff",
"kG c #c5e4ff",
"pJ c #c5e5ff",
"pn c #c5e6ff",
"UC c #c6a875",
"Bh c #c6bfba",
"Um c #c6c3bb",
"VK c #c6c5c4",
"BR c #c6c6c5",
"vK c #c6c6c6",
"NC c #c6c7c9",
"x9 c #c6daec",
"dz c #c6deff",
"e# c #c6e0ff",
"gf c #c6e1ff",
"e2 c #c6e2ff",
"gs c #c6e3ff",
"i5 c #c6e4ff",
"mg c #c6e5ff",
"pt c #c6e6ff",
"TW c #c79d29",
"G7 c #c7a405",
"Sc c #c7bdaf",
"WH c #c7c015",
"uW c #c7c6c6",
"uU c #c7c7c6",
"nP c #c7c7c7",
"JY c #c7c7c8",
"fP c #c7e0ff",
"eE c #c7e1ff",
"x7 c #c7e2fa",
"z4 c #c7e2fb",
"iR c #c7e2ff",
"fd c #c7e3ff",
"iQ c #c7e4ff",
"kx c #c7e5ff",
"pO c #c7e6ff",
"ss c #c7e7ff",
"OV c #c8b28f",
"Of c #c8c1b6",
"Mj c #c8c2a8",
"WY c #c8c7c6",
"I5 c #c8c8c3",
"FP c #c8c8c7",
"j6 c #c8c8c8",
"JZ c #c8c8d2",
"NG c #c8c9cb",
"gv c #c8e0ff",
"gM c #c8e2ff",
"ih c #c8e3ff",
"fQ c #c8e4ff",
"jt c #c8e5ff",
"oW c #c8e6ff",
"pP c #c8e7ff",
"wZ c #c8ecff",
"Mo c #c9b817",
"Sh c #c9b9a2",
"QK c #c9c6bc",
"k. c #c9c7c6",
"M9 c #c9c8be",
"Mq c #c9c8c7",
"j8 c #c9c9c9",
"IS c #c9c9cf",
"R0 c #c9cbce",
"rg c #c9cbd0",
"I0 c #c9cdd2",
"cU c #c9e2ff",
"hv c #c9e3ff",
"g0 c #c9e4ff",
"hO c #c9e5ff",
"lt c #c9e6ff",
"oz c #c9e7ff",
"LQ c #caaa37",
"Sp c #cabba0",
"WE c #cac415",
"AS c #cac89c",
"xr c #cac8c6",
"j9 c #cac9c8",
"H2 c #cac9c9",
"pa c #cacabb",
"r2 c #cacac5",
"y8 c #cacaca",
"aA c #cacddf",
".p c #cacde6",
"hx c #cae3ff",
"ez c #cae4ff",
"gy c #cae5ff",
"Dp c #cae6fe",
"gx c #cae6ff",
"k8 c #cae7ff",
"pM c #cae8ff",
"vS c #caebff",
"w5 c #cbc5bf",
"WG c #cbc911",
"WF c #cbca11",
"yY c #cbcac8",
"D4 c #cbcbcb",
"qM c #cbcbd6",
"GP c #cbcbda",
"NF c #cbcdd0",
"GT c #cbcdd5",
"dA c #cbe2ff",
"eA c #cbe4ff",
"fR c #cbe5ff",
"gw c #cbe6ff",
"mh c #cbe7ff",
"kd c #cbe8ff",
"sj c #cbe9ff",
"nv c #cbebff",
"D7 c #ccbca0",
"ES c #ccc19e",
"Os c #ccc8c1",
"CU c #cccac7",
"S. c #cccbcb",
"P4 c #cccbcc",
"ME c #ccccb4",
"AP c #ccccc2",
"M4 c #ccccc4",
"AE c #ccccc6",
"nN c #cccccc",
"RF c #cccccd",
"r1 c #ccccd0",
"zd c #ccdeed",
"v9 c #cce4f5",
"tb c #cce4ff",
"gN c #cce5ff",
"eJ c #cce6ff",
"hP c #cce7ff",
"mk c #cce8ff",
"ow c #cce9ff",
"pL c #cceaff",
"A7 c #ccebff",
"Uw c #cdb388",
"KV c #cdb998",
"x0 c #cdc7c1",
"RM c #cdcccc",
"ra c #cdcdb8",
"ph c #cdcdcd",
"J8 c #cdcdd0",
"C2 c #cdcdd9",
"RD c #cdced0",
"BQ c #cdcfd0",
"H1 c #cdcfd3",
"SL c #cdd0d4",
"eW c #cdd3e0",
"e3 c #cde3ff",
"cp c #cde4ff",
"g2 c #cde5ff",
"ed c #cde6ff",
"hi c #cde7ff",
"kC c #cde8ff",
"k7 c #cde9ff",
"mG c #cdeaff",
"xB c #cdebff",
"uT c #cecdcb",
"yW c #cecdcc",
"P# c #cecdcd",
"ui c #cecece",
"Jl c #cececf",
"p0 c #ceced7",
"Rj c #cecfd0",
"NE c #ced1d4",
"Bq c #cedff0",
"f3 c #cee5ff",
"vt c #cee6fc",
"g1 c #cee6ff",
"fg c #cee7ff",
"xN c #cee8fe",
"gg c #cee8ff",
"ke c #cee9ff",
"ov c #ceeaff",
"yC c #ceebff",
"wR c #ceecff",
"vX c #ceedff",
"Go c #cfb110",
"Od c #cfc9c3",
"tq c #cfcfcf",
"b3 c #cfd0ea",
"nR c #cfd1d5",
"d5 c #cfd1e0",
"ib c #cfd5e3",
"#l c #cfddf4",
"g4 c #cfe6ff",
"#b c #cfe7fd",
"f4 c #cfe7ff",
"e6 c #cfe8ff",
"hQ c #cfe9ff",
"m6 c #cfeaff",
"nD c #cfebff",
"k5 c #cfecff",
"Tz c #d0c4b1",
"N. c #d0cfca",
"HT c #d0d0c4",
"U2 c #d0d0ce",
"Cl c #d0d0d0",
"li c #d0d8e4",
"Hx c #d0e0ea",
"F. c #d0e4ea",
"u3 c #d0e5ff",
"iS c #d0e6ff",
"dC c #d0e7ff",
"h3 c #d0e8ff",
"ky c #d0e9ff",
"gr c #d0eaff",
"kA c #d0ebff",
"zO c #d0ecff",
"Uc c #d1aa17",
"Pr c #d1b67c",
"EV c #d1c1a8",
"HX c #d1c524",
"WU c #d1d0d0",
"B# c #d1d1d0",
"mT c #d1d1d1",
"qt c #d1d2d2",
"eV c #d1d3dc",
"An c #d1e1ee",
"bS c #d1e7ff",
"db c #d1e8ff",
"hw c #d1e9ff",
"hR c #d1eaff",
"i6 c #d1ebff",
"kz c #d1ecff",
"H. c #d2aa13",
"K2 c #d2c5a1",
"no c #d2d1d1",
"M8 c #d2d2cc",
"mA c #d2d2d2",
"gG c #d2d3d6",
"bw c #d2d3ec",
"BP c #d2d4d7",
"Hw c #d2e3ef",
"dE c #d2e8ff",
"cL c #d2e9ff",
"hh c #d2eaff",
"fr c #d2ebff",
"jL c #d2ecff",
"wM c #d2f1ff",
"KS c #d3c4a4",
"Sx c #d3cbc3",
"nO c #d3d3d3",
"QJ c #d3d3d4",
"BU c #d3d3d9",
"ia c #d3d4d5",
"#L c #d3d5e3",
"wk c #d3e6f2",
"gh c #d3e6ff",
"dD c #d3e7ff",
"dc c #d3e9ff",
"dd c #d3eaff",
"dF c #d3ebff",
"h2 c #d3ecff",
"m8 c #d3edff",
"lS c #d3eeff",
"wi c #d3efff",
"Tf c #d4b05d",
"yX c #d4d3d2",
"j5 c #d4d4d4",
"Ri c #d4d5d6",
"NB c #d4d5d7",
"pg c #d4d6d5",
".P c #d4d7ee",
"OM c #d4e4ec",
"Hv c #d4e5f0",
"eF c #d4e8ff",
"dN c #d4e9ff",
"qc c #d4eafd",
"cN c #d4eaff",
"de c #d4ebff",
"fc c #d4ecff",
"jM c #d4edff",
"Jr c #d4eefa",
"kD c #d4eeff",
"Uf c #d5b11d",
"P6 c #d5b43a",
"Tw c #d5b772",
"Ff c #d5c090",
"Mv c #d5c811",
"Km c #d5d3d2",
"Ju c #d5d4d3",
"p# c #d5d5d0",
"oK c #d5d5d5",
"Q6 c #d5d5da",
"hZ c #d5e7ff",
"eB c #d5e8ff",
"bq c #d5e9ff",
"cO c #d5eaff",
"cP c #d5ebff",
"xl c #d5ecfa",
"dG c #d5ecff",
"e7 c #d5edff",
"lT c #d5eeff",
"Ep c #d5f0ff",
"tG c #d5f1ff",
"Sg c #d6c6af",
"pd c #d6d4ab",
"V# c #d6d4ce",
"Ik c #d6d5d3",
"AO c #d6d6d2",
"Ij c #d6d6d3",
"Rw c #d6d6d4",
"sC c #d6d6d6",
"Fd c #d6d7d6",
"Jg c #d6d7d7",
"c0 c #d6d7e9",
"hY c #d6e8ff",
"fE c #d6e9ff",
".V c #d6eaff",
"cM c #d6ebff",
"df c #d6ecff",
"e8 c #d6edff",
"hS c #d6eeff",
"jP c #d6efff",
"LB c #d7b759",
"D3 c #d7d6d6",
"M7 c #d7d7d5",
"C1 c #d7d7d6",
"sw c #d7d7d7",
"qT c #d7d8d9",
".6 c #d7daef",
"SK c #d7dbe0",
"hW c #d7e9ff",
"cV c #d7ebff",
"dM c #d7ecff",
"e9 c #d7edff",
"ec c #d7eeff",
"nA c #d7efff",
"wL c #d7f4ff",
"wN c #d7f5ff",
"U0 c #d8bf07",
"OQ c #d8c4a1",
"Sd c #d8cdbd",
"Mt c #d8ce11",
"QI c #d8d6d4",
"PN c #d8d7d7",
"Jw c #d8d8d7",
"lN c #d8d8d8",
"mP c #d8d8da",
"HS c #d8d8dc",
"JP c #d8d8df",
"Ox c #d8d9d8",
"sl c #d8ebff",
".Y c #d8ecff",
"dJ c #d8edff",
"dH c #d8eeff",
"ju c #d8efff",
"gl c #d8f0ff",
"rI c #d9d9d9",
"xq c #d9d9da",
"kk c #d9d9db",
"hE c #d9d9dd",
"Rh c #d9dadb",
"hX c #d9eaff",
"jv c #d9ebff",
"cl c #d9ecff",
"cQ c #d9edff",
"eb c #d9eeff",
"f. c #d9efff",
"mH c #d9f0ff",
"wP c #d9f1ff",
"rS c #d9f2ff",
"tx c #d9f4ff",
"J# c #dac8b7",
"AK c #dadada",
"#9 c #dadff3",
"cq c #daecff",
"bX c #daedff",
"dh c #daeeff",
"#5 c #daefff",
"if c #daf0ff",
"gm c #daf1ff",
"z2 c #daf2ff",
"yQ c #daf4ff",
"rR c #daf5ff",
"Fy c #daf6ff",
"S4 c #dbad4d",
"TN c #dbaf16",
"K1 c #dbc8a1",
"MG c #dbda38",
"Jd c #dbdada",
"FU c #dbdbdb",
"qL c #dbdbdc",
"CC c #dbe7f2",
"hV c #dbecff",
"cm c #dbedff",
"cR c #dbeeff",
"dI c #dbefff",
"fH c #dbf0ff",
"h1 c #dbf1ff",
"rP c #dbf4ff",
"rQ c #dbf5ff",
"EU c #dcc39c",
"O2 c #dcc59c",
"Ml c #dccf0b",
"T7 c #dcd3bd",
"HU c #dcdb7d",
"H6 c #dcdcdb",
"py c #dcdcdc",
"M2 c #dcdcdd",
"rc c #dcdd49",
"t9 c #dcedff",
"bL c #dceeff",
"dg c #dcefff",
"f# c #dcf0ff",
"fK c #dcf1ff",
"yO c #dcf3ff",
"wJ c #dcf4ff",
"Cg c #dcf5ff",
"Az c #dcf6ff",
"S9 c #ddae3f",
"Vh c #ddaf50",
"E. c #ddcaa9",
"K3 c #ddcca5",
"Mu c #ddd509",
"vJ c #dddddc",
"nq c #dddddd",
"r# c #dddde3",
"J0 c #ddde7a",
"AF c #dddf5d",
"GM c #dde8ef",
"DL c #ddeaf4",
"a9 c #ddeeff",
"bM c #ddefff",
"cS c #ddf0ff",
"dL c #ddf1ff",
"gn c #ddf2ff",
"wO c #ddf6ff",
"p7 c #dec3a8",
"Id c #deca07",
"rd c #ded446",
"tp c #dedddc",
"z7 c #dedddd",
"sB c #dededd",
"tR c #dedede",
"QV c #dededf",
"I4 c #dedee2",
"C9 c #dedfe3",
"bv c #dedfe4",
"BO c #dee0e2",
"bN c #deefff",
"bV c #def0ff",
"cT c #def1ff",
"fJ c #def2ff",
"Bp c #def3ff",
"uy c #def7ff",
"Mn c #dfd307",
"vN c #dfdddc",
"uO c #dfddde",
"Gt c #dfdedd",
"Mg c #dfdede",
"AG c #dfdf35",
"Fv c #dfdfde",
"wD c #dfdfdf",
"p. c #dfdfe0",
"mB c #dfe0e0",
"tQ c #dfe0e1",
"c3 c #dfe8f7",
"ff c #dfeeff",
"bO c #dfefff",
"cn c #dff0ff",
"bP c #dff1ff",
"Hy c #dff2f3",
"JM c #dff2fc",
"co c #dff2ff",
"gq c #dff3ff",
"yD c #dff5ff",
"wK c #dff9ff",
"Ul c #e0bb09",
"H0 c #e0cdb9",
"qs c #e0dfdf",
"IU c #e0e038",
"I6 c #e0e059",
"Ni c #e0e0dd",
"AM c #e0e0df",
"lE c #e0e0e0",
"#w c #e0ebf8",
"sk c #e0efff",
"cr c #e0f0ff",
"bk c #e0f1ff",
"bU c #e0f2ff",
"fa c #e0f3ff",
"vs c #e0f6ff",
"B6 c #e0f7ff",
"Gw c #e0f8ff",
"IZ c #e1cab6",
"OU c #e1cba6",
"Mm c #e1db05",
"NV c #e1e1e0",
"zv c #e1e1e1",
"qm c #e1e1e5",
"MF c #e1e259",
"C3 c #e1e299",
"JQ c #e1e2db",
"fo c #e1e2e3",
"dU c #e1e2e4",
"D2 c #e1e3e8",
"be c #e1e3e9",
"hU c #e1efff",
"bK c #e1f0ff",
"bl c #e1f1ff",
"bQ c #e1f2ff",
"fI c #e1f3ff",
"bJ c #e1f4ff",
"Dq c #e1f5ff",
"ty c #e1f7ff",
"wn c #e2e1e0",
"Il c #e2e1e1",
"rb c #e2e26e",
"Kl c #e2e2e0",
"jg c #e2e2e2",
"RE c #e2e3e2",
"RZ c #e2e3e6",
"Ow c #e2e4ea",
"CS c #e2e8f6",
"aN c #e2f0ff",
"bj c #e2f1ff",
"bR c #e2f2ff",
"bp c #e2f3ff",
"ig c #e2f4ff",
"go c #e2f5ff",
"HP c #e2f8ff",
"P1 c #e2faff",
"B1 c #e3be91",
"QS c #e3ca04",
"KU c #e3d0af",
"Sf c #e3d2b8",
"O5 c #e3d7b4",
"K5 c #e3dcd0",
"HW c #e3e23e",
"jf c #e3e3e3",
"LW c #e3e3e4",
"P. c #e3e3e5",
"AD c #e3e3e7",
"Jf c #e3e4e4",
"ND c #e3e6ea",
"bG c #e3e8f5",
"NU c #e3eaf9",
"bW c #e3f1ff",
"bm c #e3f2ff",
"bn c #e3f3ff",
"OL c #e3f4f8",
"hg c #e3f4ff",
"zP c #e3f9ff",
"Dr c #e3fbff",
"Eo c #e3fcff",
"rf c #e4ceb2",
"OR c #e4d2b1",
"El c #e4e3e3",
"kW c #e4e4e4",
"BF c #e4e5ea",
"to c #e4e6ea",
"iY c #e4e9f1",
"bT c #e4f2ff",
"bo c #e4f3ff",
"br c #e4f4ff",
"vh c #e4fafd",
"LK c #e5b716",
"KT c #e5d4b3",
"VW c #e5d7b9",
"pf c #e5e2df",
"Re c #e5e4e3",
"R8 c #e5e4e4",
"rH c #e5e5e4",
"lh c #e5e5e5",
"Mf c #e5e5e6",
"MD c #e5e5ed",
"M1 c #e5e6e7",
"Mi c #e5e6eb",
"Gs c #e5e7ee",
"uN c #e5e8f7",
"sA c #e5e9f2",
"am c #e5f2ff",
"an c #e5f3ff",
"a4 c #e5f4ff",
"ep c #e5f5ff",
"x# c #e5f6ff",
"HO c #e5fbff",
"Q3 c #e6d004",
"UL c #e6d101",
"Tg c #e6e3de",
"BW c #e6e536",
"KP c #e6e5e4",
"AL c #e6e5e5",
"VT c #e6e6e2",
"uh c #e6e6e5",
"wz c #e6e6e6",
"KI c #e6e6e7",
"of c #e6e6e8",
"JX c #e6e7e6",
"Ho c #e6e7e7",
"#h c #e6e7f0",
"Ly c #e6e9f2",
"rG c #e6eaef",
"tP c #e6eaf4",
"Fu c #e6eaf6",
"dq c #e6eefa",
"a6 c #e6f3ff",
"a5 c #e6f4ff",
"b# c #e6f5ff",
"BB c #e6f9ff",
"UK c #e7c035",
"Uv c #e7cea5",
"Ss c #e7d2b2",
"I8 c #e7e116",
"lM c #e7e7e7",
"xx c #e7e7e8",
"HV c #e7e864",
"fu c #e7e8ec",
"Lu c #e7e9f1",
"Ek c #e7ecf4",
"al c #e7f4ff",
"aq c #e7f5ff",
"a7 c #e7f6ff",
"wj c #e7f9ff",
"IQ c #e7fcff",
"uo c #e7fdff",
"UD c #e8cd9e",
"UU c #e8d103",
"Uq c #e8d2a6",
"Lx c #e8e1c8",
"sz c #e8e4d5",
"J5 c #e8e4e6",
"zI c #e8e7e7",
"qN c #e8e883",
"pZ c #e8e8e6",
"vO c #e8e8e8",
"zB c #e8e8e9",
".5 c #e8e9ed",
"aZ c #e8e9ef",
"Me c #e8ebf5",
"KO c #e8ecf1",
"aa c #e8f4fc",
"ao c #e8f4ff",
"ap c #e8f5ff",
"a3 c #e8f6ff",
"aE c #e8f7ff",
"IP c #e8fbff",
"yi c #e8fdff",
"Tn c #e9c776",
"D9 c #e9d7b7",
"D8 c #e9d7b8",
"Ft c #e9e0c2",
"AU c #e9e5e0",
"VS c #e9e8e6",
"VU c #e9e9e7",
"H5 c #e9e9e8",
"yq c #e9e9e9",
"cG c #e9e9f3",
"Ia c #e9eaeb",
"du c #e9eaf2",
".r c #e9eaf6",
"rF c #e9ebf2",
"sW c #e9effc",
"KH c #e9effd",
"d0 c #e9f4ff",
"ak c #e9f6ff",
"aF c #e9f7ff",
"b. c #e9f8ff",
"EZ c #e9ffff",
"Wr c #eac502",
"K4 c #ead2a9",
"Ur c #ead7b1",
"O3 c #ead8b2",
"St c #eadbc7",
"Tx c #eae7e4",
"Ej c #eae7e5",
"KN c #eae9ec",
"VV c #eaeae8",
"zq c #eaeae9",
"mx c #eaeaea",
"gH c #eaecf2",
"ch c #eaedf6",
"c4 c #eaf5ff",
"aU c #eaf6ff",
"aG c #eaf7ff",
"aT c #eaf8ff",
"QM c #ebd404",
"OT c #ebd8b6",
"qS c #ebeaef",
"lH c #ebebeb",
"I# c #ebeeed",
"tn c #ebeefc",
"JW c #ebf1fd",
"ar c #ebf5ff",
"#3 c #ebf6ff",
"#V c #ebf7ff",
"aH c #ebf8ff",
"x8 c #ebfdff",
"Ay c #ebfeff",
"EY c #ebffff",
"T8 c #ecc80d",
"MI c #ecd2aa",
"Uo c #ecd5b0",
"r7 c #ecd8c3",
"NT c #ecddb3",
"tO c #ecdea6",
"CR c #ecdfb9",
"C8 c #ece7e6",
"Bi c #ecebeb",
"iG c #ececec",
"GV c #eceff2",
"Mh c #eceffa",
"dY c #ecf7ff",
"aS c #ecf8ff",
"d2 c #ecf9ff",
"#n c #ecfbff",
"PD c #edb31d",
"AI c #edd2a8",
"Lt c #edd67f",
"QY c #eddb03",
"sV c #eddcb7",
"O4 c #eddeba",
"p2 c #eded26",
"ql c #ededec",
"mS c #ededed",
"b1 c #edeef1",
"bF c #edeef6",
"Gr c #edf0fc",
"aj c #edf6ff",
"a8 c #edf7ff",
"#U c #edf8ff",
"#2 c #edf9ff",
"DJ c #edfaff",
"xk c #edfcff",
"zc c #edfeff",
"V6 c #eeb60c",
"VF c #eeb71a",
"Ti c #eec87b",
"Tr c #eecd72",
"UH c #eee4c0",
"Ig c #eeeded",
"CP c #eeeeed",
"EQ c #eeeeee",
"D1 c #eeeffa",
"zu c #eef0f2",
"L0 c #eef0f4",
"as c #eef6ff",
"ac c #eef8ff",
"CB c #eef9ff",
".X c #eefaff",
"eT c #eefbff",
"Am c #eefeff",
"DW c #eeffff",
"KG c #efd593",
"r3 c #efee42",
"M3 c #efeeec",
"zA c #efefee",
"lI c #efefef",
"xw c #efeff0",
"d6 c #eff1f7",
"ai c #eff7ff",
"dZ c #eff8ff",
"ad c #eff9ff",
"ae c #effaff",
"bi c #effdff",
"Wy c #f0d200",
"JV c #f0d6af",
"Nl c #f0dec9",
"BJ c #f0e0d1",
"LR c #f0eeeb",
"Wi c #f0efee",
"oM c #f0efef",
"wy c #f0f0f0",
"vI c #f0f0f1",
"cg c #f0f0f4",
"rY c #f0f1f2",
"vE c #f0f1f3",
"aM c #f0f7ff",
"d1 c #f0f8ff",
"## c #f0f9ff",
"#G c #f0faff",
"#1 c #f0fbff",
"ba c #f0fcff",
"DK c #f0feff",
"eS c #f0ffff",
"Fn c #f1ba27",
"LH c #f1c01b",
"Gi c #f1d302",
"Uu c #f1dcb6",
"sy c #f1dd8e",
"UE c #f1e0b7",
"Th c #f1ece4",
"Vg c #f1efec",
"xv c #f1f1f1",
"az c #f1f2f5",
"uM c #f1f2fb",
"aR c #f1faff",
"af c #f1fbff",
"dr c #f1fcff",
"cB c #f1fdff",
"Pm c #f1ffff",
"Wk c #f2d501",
"OS c #f2dfbc",
"UI c #f2e2a8",
"MZ c #f2f2f1",
"Jn c #f2f2f2",
"BG c #f2f382",
"q6 c #f2f3f4",
"BN c #f2f3f6",
"#g c #f2f3f8",
"Md c #f2f3fa",
"Rg c #f2f4f5",
"GU c #f2f6ff",
"#y c #f2faff",
"aI c #f2fbff",
"#W c #f2fcff",
"Gx c #f2fdff",
"Dc c #f2ffff",
"Lw c #f3de89",
"kV c #f3f3f3",
"wu c #f3f3f4",
"aO c #f3f9ff",
"#z c #f3faff",
"#R c #f3fbff",
".W c #f3fcff",
"#X c #f3fdff",
"aD c #f3ffff",
"rE c #f4cb52",
"Tk c #f4da92",
"ET c #f4dfb2",
"Fs c #f4e197",
"OO c #f4e1c3",
"NQ c #f4f4f3",
"kS c #f4f4f4",
".O c #f4f4f9",
"aK c #f4f9ff",
"aP c #f4faff",
"#F c #f4fbff",
"#S c #f4fcff",
"#Y c #f4fdff",
"Gy c #f4feff",
"Py c #f5bb35",
"qR c #f5c46d",
"Up c #f5d49e",
"AH c #f5d74c",
"Ut c #f5e2be",
"UG c #f5e8c3",
"Q2 c #f5e900",
"Jv c #f5f4f3",
"np c #f5f5f5",
"I7 c #f5f639",
"Nj c #f5f656",
".# c #f5f6fa",
"#M c #f5f6fb",
"qr c #f5fafe",
"aL c #f5faff",
"at c #f5fcff",
"#a c #f5feff",
"aV c #f5ffff",
"TO c #f6cd1c",
"Te c #f6d57a",
"UO c #f6d900",
"MH c #f6d959",
"Wv c #f6db00",
"wB c #f6f6f6",
"tm c #f6f6f8",
"em c #f6f7fa",
"kl c #f6f8fa",
"aJ c #f6faff",
"ag c #f6fdff",
"#Z c #f6feff",
"av c #f6ffff",
"Vv c #f7ba23",
"J4 c #f7bc53",
"C7 c #f7be51",
"Ei c #f7c935",
"KM c #f7c940",
"Us c #f7e4bf",
"QR c #f7e900",
"Ls c #f7edc3",
"KQ c #f7efe2",
"QZ c #f7f100",
"SH c #f7f2ea",
"He c #f7f6f6",
"r. c #f7f7f6",
"l8 c #f7f7f7",
"qi c #f7f7f8",
"#s c #f7f7f9",
"dV c #f7f7fa",
"#4 c #f7fcff",
"au c #f7fdff",
"#A c #f7feff",
"#0 c #f7ffff",
"VX c #f8c701",
"HZ c #f8d584",
"UJ c #f8d681",
"Tv c #f8d882",
"CQ c #f8e38b",
"D5 c #f8e6c9",
"UF c #f8e8c1",
"p4 c #f8ee03",
"P5 c #f8f6f1",
"el c #f8f8f8",
"aQ c #f8fcff",
"ah c #f8fdff",
"#E c #f8feff",
"eq c #f8ffff",
"Qn c #f9cc06",
"NS c #f9dc5f",
"Tm c #f9dc93",
"UZ c #f9e400",
"QN c #f9ef00",
"UM c #f9f100",
"tN c #f9f1d3",
"pe c #f9f7e3",
"AT c #f9f8e1",
"cw c #f9f9f9",
"sS c #f9fae6",
"#x c #f9feff",
"#D c #f9ffff",
"SX c #fad582",
"S3 c #fad98c",
"OP c #fadbad",
"BY c #faf204",
"Q1 c #faf400",
"Sv c #faf5ed",
"Su c #faf9f8",
"LV c #fafaf9",
"nj c #fafafa",
"gS c #fafafb",
"sR c #fafaff",
"KJ c #fafbff",
"#T c #fafdff",
"#H c #fafeff",
"#B c #faffff",
"Vp c #fbc343",
"Tj c #fbda8e",
"D6 c #fbe2ba",
"rC c #fbf286",
"Q0 c #fbf500",
"KK c #fbf58c",
"Eg c #fbf6a3",
"JR c #fbfa40",
"KD c #fbfae0",
"Pq c #fbfaf9",
"D0 c #fbfafc",
"Ef c #fbfbfa",
"iF c #fbfbfb",
"Ov c #fbfbff",
"ol c #fbfcfe",
"#C c #fbffff",
"Nk c #fcc31b",
"sU c #fcc90c",
"KR c #fce1b5",
"KE c #fce32c",
"UV c #fced00",
"sx c #fcfbfa",
"hr c #fcfcfc",
"b2 c #fcfcfe",
"rB c #fcfdff",
"zH c #fcfeff",
"#Q c #fcffff",
"IY c #fda913",
"r6 c #fdb81c",
"JU c #fdbd0e",
"BI c #fdc721",
"Ps c #fdcc4b",
"T. c #fddd84",
"Tl c #fddf96",
"I9 c #fde035",
"QQ c #fdf600",
"QO c #fdf700",
"QP c #fdf800",
"Un c #fdfcf9",
"Lv c #fdfcfa",
"LA c #fdfcfb",
"SI c #fdfcfc",
"NR c #fdfdf3",
"U3 c #fdfdfc",
"f8 c #fdfdfd",
"fv c #fdfdfe",
"rA c #fdfdff",
"yp c #fdfefd",
"Fr c #fdfeff",
"ab c #fdffff",
"KF c #fec900",
"J. c #fec958",
"Qh c #fed100",
"rD c #fed200",
"Eh c #fed702",
"VE c #fed973",
"BZ c #fedf0d",
"Ts c #fee08c",
"Tt c #fee492",
"Tu c #fee493",
"Td c #fee799",
"sT c #feeb3c",
"FQ c #fefdfd",
".q c #fefefe",
"cH c #fefeff",
"#m c #feffff",
"p6 c #ffb925",
"B0 c #ffbe1c",
"qQ c #ffc400",
"J3 c #ffc700",
"IX c #ffc900",
"C6 c #ffca00",
"V4 c #ffcb15",
"Wf c #ffcc0b",
"W# c #ffce0c",
"We c #ffce0d",
"V3 c #ffce14",
"Fg c #ffce3e",
"VZ c #ffcf14",
"V5 c #ffd00a",
"V0 c #ffd014",
"Wa c #ffd10d",
"VY c #ffd110",
"V2 c #ffd115",
"Wd c #ffd20d",
"TP c #ffd21b",
"TT c #ffd21d",
"Wb c #ffd30d",
"V1 c #ffd315",
"TS c #ffd31c",
"Qa c #ffd40b",
"T1 c #ffd415",
"T3 c #ffd416",
"P9 c #ffd50b",
"Qb c #ffd50c",
"Wc c #ffd50d",
"T2 c #ffd513",
"TR c #ffd51c",
"TU c #ffd521",
"Vi c #ffd565",
"KL c #ffd600",
"Q# c #ffd60b",
"TQ c #ffd61c",
"Fm c #ffd65e",
"JT c #ffd700",
"P8 c #ffd70b",
"T5 c #ffd807",
"Q. c #ffd80b",
"Fl c #ffd968",
"Wg c #ffda02",
"Qj c #ffda07",
"TV c #ffda0b",
"FZ c #ffda4f",
"Fk c #ffda66",
"Qk c #ffdb06",
"T0 c #ffdb1a",
"Fj c #ffdb66",
"Fh c #ffdb6f",
"Px c #ffdb79",
"VD c #ffdb7c",
"Qc c #ffdc02",
"p5 c #ffdc11",
"T4 c #ffdc19",
"Ql c #ffdd0a",
"PE c #ffdd6d",
"VC c #ffdd77",
"Vz c #ffde71",
"Vy c #ffde72",
"Vw c #ffde75",
"r5 c #ffdf00",
"Qi c #ffdf06",
"PF c #ffdf6b",
"VA c #ffdf72",
"Vx c #ffdf76",
"Pw c #ffdf79",
"Pt c #ffdf82",
"G8 c #ffe007",
"PG c #ffe06b",
"Fi c #ffe06d",
"Vm c #ffe081",
"Vn c #ffe084",
"Vo c #ffe086",
"G9 c #ffe104",
"PH c #ffe16e",
"VB c #ffe175",
"FY c #ffe179",
"Pv c #ffe17a",
"Wq c #ffe200",
"Vj c #ffe28d",
"P7 c #ffe309",
"Qm c #ffe30b",
"LE c #ffe43f",
"LF c #ffe441",
"re c #ffe47d",
"Vl c #ffe484",
"S2 c #ffe499",
"FX c #ffe572",
"Vk c #ffe68a",
"S0 c #ffe69c",
"Gn c #ffe702",
"LG c #ffe73d",
"Pu c #ffe782",
"T# c #ffe792",
"S1 c #ffe79d",
"Wl c #ffe800",
"Ub c #ffe810",
"qP c #ffe900",
"LM c #ffe939",
"IW c #ffea00",
"Gm c #ffea01",
"LN c #ffea3a",
"Ta c #ffea96",
"Wp c #ffeb00",
"Gj c #ffeb01",
"Ua c #ffeb13",
"LC c #ffeb3f",
"SZ c #ffeba0",
"C5 c #ffec00",
"Gk c #ffec01",
"Ug c #ffec0f",
"U# c #ffec11",
"Uk c #ffec13",
"Ww c #ffed00",
"Gl c #ffed01",
"Uh c #ffed0d",
"Uj c #ffed0e",
"LO c #ffed41",
"LD c #ffed4b",
"Tb c #ffed9a",
"JS c #ffee00",
"U. c #ffee14",
"T9 c #ffee19",
"HY c #ffee70",
"BH c #ffef00",
"Ui c #ffef0c",
"LL c #ffef35",
"J2 c #fff000",
"SY c #fff0a2",
"Wx c #fff100",
"Wm c #fff200",
"Tc c #fff29f",
"Wo c #fff300",
"LP c #fff33b",
"Wn c #fff400",
"UY c #fff500",
"UW c #fff800",
"UX c #fff900",
"UN c #fffa00",
"IV c #fffc00",
"qO c #fffc06",
"C4 c #fffc10",
"J1 c #fffe00",
"r4 c #ffff00",
"BX c #ffff11",
"p3 c #ffff12",
"x1 c #fffffe",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.h.i.j.k.l.m.n.o.p.qQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.r.s.t.u.v.w.x.y.z.A.B.C.C.D.E.F.G.H.I.J.K.L.M.N.OQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.P.Q.R.S.T.U.V.WQtQtQtQtQtQtQtQtQtQtQtQt.X.Y.Z.0.1.2.3.4.5QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.6.7.8.9#.##QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#a#b#c#d#e#f#gQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#h#i#j#k#lQtQtQtQtQt#m#m#m#m#m#m#m#m#m#m#m#m#m#m#m#m#mQtQtQtQt#n#o#p#q#r#sQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#t#u#v#wQtQt#x#y#z#A#B#B#C#B#B#B#B#D#D#D#D#D#B#B#B#B#B#C#C#E#F#G#HQt#B#I#J#K#LQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#M#N#O#PQt#Q#R#S#E#T#R#U#V#U#G#W#X#Y#a#Z#A#0#A#Z#Z#a#Y#W#1#2#3#3###4#H#Z#xQt#5#6#7#8.qQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#9a.a#aaab#Gacadadaeafagahagaiajakalamanalaoapaoalanananaqarasatahau#R#Gaead###BavawaxayazQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtaAaBaCaDafaEaFaG#3#VaHaHaH#2#GaIagauaJaKaKaLaMaNaOaP#zaOaPaQ#E.WaR#2aSaSaSaHaT#VaUaeaVaWaXaYaZQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQta0a1a2ava3ana4a5a6aqa7apapapa3a3akaFaGaTaSac#1a8a9##aR.XaSaTaGaFb.aEaka3a3apapapa7b#anaobabbbcbdbeQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtbfbgbhbibjbkblblbjbmbnboamanana4a4a5a5a5b#b#b#a7bpbqbrb#b#b#b#b#b#a5a5a5a4a4boanambobnbmbjbmaTbsbtbubvQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtbwbxbybzbAbBbCbDbEbFQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtbGbHbIbJbKbLbMbNbObPbkbkbkbQbRbRbmbmboboboboboana5blbSbmananananbobobobobTbTbmbRbRbUbkbkbPbPbVbWbXbYbZb0b1QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtb2b3b4b5b6b7b8b9c.c#cacbcccdcecfcgQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtchcicjckbO.YclclbXcmbLbMbNcncnbPbPcobUbUbUbQbRbRbRbrbVcpbkbpbpbpbRbRbRbQbUbUbUcobPbPcncnbNa9bLcmcqcrcsctcucvcwQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtcxcyczcA#UQtQtQtQtQtQtQtQtQtcBcCcDcEcFcGQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtcHcIcJcKcLcMcNcOcPcM.YclcQbXbLcRbMcScSbVbVcTbkbkbkbkbRcRcUbNbkbkbkbkbkbkbPcTcTbVbVbMbMcRbLbXclcl.YcV.YcPcWcXcYcZQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtc0c1c2c3QtQtQtabab#m#m#m#m#m#m#mQtQtQtc4c5c6c7.qQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtc8c9d.d#dadbdcdcdddecMdf.YclcQbXbXcRdgbMbNbVcTbVcTbPbQdhdidgbPbPbPbPbPcTcTbVbMbMdgbLbXbXcQcl.YdfcVcOddcndjdkdldmdnQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtdodpdqQtQtah#z##afafaf.W#Y#Y.WaIdraR###zQtQtdrdsdtduQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtdvdwdxdydzdAdBdCdDbSdEdddFdGcMcVclcldHcQbXdIbMbMbNbNcScodJdKdgbPdLdLcSbMbNbNbMdIbXcQcl.Ycl.YdMcPdddddN.VdOdPdQdRdSdTdUQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtdVdWdX#B#adYaS.XaRaR##dZa8acd0ajacdYd1#G#yaR.Xd2.Wabd3d4d5QtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtd6d7d8d9e.dEcne#eae#dbdEdbcLdddecPdMdMdJdJcQeb#5dIdIbMbMcoecdO#5cTdLcSbMbMdgdI#5cQcQcQ.Y.YdMcPdecNcNcOedeeefbRegeheiejekelQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtemeneo#Dalbna5a5alaqa3aGdY#VacbWak#2#V#VaGa3aqaqaqepa5eqeresetQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQteuevewexeyezeAcreBeCeDeEeFcNdcdddFdGdM.YdJcQcQeb#5#5#5dgbPdMeG#5cTcScSdg#5#5#5dhcQcQdJ.YdMdededfdMedeHeIdKbTeJeKeLeMeNeOePQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtcHeQeReSbObMcnbkblbjbpbnbnboboa4cqcnb#a4bnbTbobobnbjblbkcreTbseUeVQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQteWeXeYeZe0e1e2e2e2dMbme3e4e4e5e6dfe7dGe8dMe9dJcQf.#5#5#5f#fae8fb#5cTdLdLf##5#5#5f.cQdJebcQe9dHfcfdfeeIeGffcnfgfhfifjfkflfmfnfoQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtfpfqfrbMdfcQbXbLbMbMdLbPbkblblbRcNbLbnbQblblbPbPcTbNbMcRbXbLdJfsftfuQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtfvfwfxfyfzfAfBfCfDe2e2eJcnbTfEfFe4.DfGeJdFdhdIdIfHfHfHfHdLcTfIdfeH#5bPdLcTfJfJfKfKdLdLf#e9dbfLfMfNfOfPffbocOfQfRfSfTfUfVfWfXfYfZQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtf0f1f2f3dbbqcNdfdMclbXcRdgbVbVcTbUf4dJbQbPcTbVcSdgcRbXcQdMcMe9cQf5f6f7f8QtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtf9g.g#gagbgcgdgegffDfdfQfdggcRa6bjghgigjeCgegke2fgfcglgmgncogodHgpdLfIgqfJdLfHf.grgsgtgegugu.CgvbLalbRcOgwgxgyfRgtgzgAgBgCgDgEgFgGQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtgHgIgJgKcVgLgMdccNdFdfdMdJcQcRdgdgcngNdfcobMdgdgdhcQdJdMdfdMcNfDgOgjgPgQgRQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtgSgTgUgVgWgXgYcWfegZfSgZfQg0gwgyg1cPcoa7aGg2g3g4g5g6geeHg7g8geg9g9h.h#hahbhcdBhddB.Dhehfh.bNana3hg#5hhfgg4higwgyfRhjhkhlhmgXhnhohphqhrQtQtQtQtQtQtQtQtQtQtQtQtQtQthshthufedcdcgidOhvhwdee9dhdhdI#5dIcohxdGgqcSdIfHdIcR#5e8hwfDhyhzcVhAhBhChDhEQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQthFhGhHgWgahIhJhKhLhMhNfDfdhOfRhPf4hQgrhRhShTgf#2aG#VaFb#bWhUhVeBhWhXhYhZfEffffbob#aT#Ublh0h1#5e8h2hhhhh3dChPgwgyfQh4h5h6h7h8h9gzi.i#iaQtQtQtQtQtQtQtQtQtQtQtQtQtibicidiehbfdg0cPbqcUgifDezh3dddHifdLigihdfigfJf#ecdFh3eEfCiie#.VcMe6ijikiliminhrQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtioipiqiriseMfTitiuivfDiwgsg0gwhPe6hRfrh2hSgeixecdGe8ebf#cTbPbUfIfIfIfIfIfIcofJdLdIdHdGdfh.eJece7e7h2frhhh3higwgwhAbsiyiyhJiziAiBiCiDiEiFQtQtQtQtQtQtQtiGiHiIiJiKiLiMiNiOiPe2e2iQhi.Ydh.Ye5ixhxhvfQg0fdh#ixiRgMeEihdKgjiScOdIebdbgyediTiriUiViWiXQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtiYiZi0cWhKi1h7fTi2i3i4hNgZi5hOgwhPhQi6frh2e7i7gZece7e7dGdGdGfcfcdGdGdGdGdGdGdGdGdGdGe8e8eci8iwhSfch2h2h2hRhQgghPhOi9j.bsj#jajbjceKh5jdjejfQtQtQtQtQtjgjhjijjjkjljmjnjojpjqjrjse2jtgyhifrjufSddbQbPbNbLclbXjvcla9bMbUcRjwiff.h2hQgghigsjxh6jyjzjAjBQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtjCjDjEjFjGjHjIjJjJiybsjKgsi5hOgwfghQi6jLjLjMjNjte7fcfcfcfcjMjMjMe7e7e7e7e7e7e7e7jMjMfcfce8h0jOjPjLh2jLjLi6hwgghijQjRjSjTjUjVjWjXjYjZj0j1j2QtQtQtiFjkj3j4j5j6j7j6j8j9k.k#kakbkckdfQeJhQfrfchAhie8dGe8hSdHebdHdHece8e8e8g7kejMh2fre6ggivkfjTkgkhkikjkkQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtklkmhHknkokpkqkrksj#ktkukvkwkxgxhPe6kygrgrkzkAkBkCh2jLjLjLh2h2h2h2fcfcfcfcfcfcfch2h2h2h2jLkDkEkFjui6i6kAgrgrhwkykGkHkIkJkKkLkMkNkOfTkPikkQkRkSQtelkTkUiGiFkVkWkXjmjlkYkZk0k1k2k3k4k5ggkyi6i6k6k7jMh2h2h2fcfcfcfcfch2fcjMg9k8h2i6hRhRi5k9kvl.i3l#lalblcQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtiFldlekTlflgkYlhQtQtQtQtliljlki8lld9lmlniyjUlolplqlrlshPhPkCggkehQhRlti8i6jLfrfrfrjLh2h2h2h2h2h2h2h2h2h2h2h2h2jLjLjMlulveci6kykykykehQltkwlwlxk9lykKjTlzlllAlBi7lClDlEiFlFlGlHQtQtQtQtlIlJlKlLjglMlNlOlPlQlRlSkCkehPgegrh2jLjLdehShShSe7h2frjLlTgeiwh2hQkeltkwlUk9lVlqlWlXlYlZcwQtQtQtQt",
"QtQtQtQtQtQtQtQtl0l1lKl2l3l4l5jml6l7l8QtQtl9m.m#mafembgamcmdjTjSkJk9memfmghihPmhhPhihwfLmigrkAi6frfri6frfrh2h2h2h2h2h2h2jLfrdFjLi6frjMhMmjdegrgrkehimkmgmlmmmmmfmemnkJlzmompmqmrmsm#mtmumvmwl2.qQtQtiFmxmymzmAQtQtQthrmBmCmDmEmFmGhPfQluhQhhh2glh2mhhOgxkAmHhSfrjMg8mIjLmki5mlmJmKmLkLkgmMmimNmOmPQtQtQtQt",
"QtQtQtQtQtQtf8mQmRjgmSmTmUj4mVmUmWkZmXjgQtmYmZhkhKm0gfm1m2iymim3lrlxmfm4mmm5gxgwmhmhm6hAm7grgrgri6i6i6jMhSglglmHglifmHglhSh2i6fri6i6m8fLm9kyhRkCmkk8jsmlkwmJmJmmn.n.n#nanbncndlpnejYnfngnhnil5QtQtnjkVnknlnmnnnoQtnpkWnqnrnsntnunvk8nwcshRe9gxnxhlnyjJhlfBnzmIhSnAnBnCnDmgkGnEmKnFhkmMkEnCnGnHnInJQtQtQtQt",
"QtQtQtQtQtnjnKnLf8QtQt.qj8l6nMnNnOnPkZnQnRnSnThkhknUh4g0nVnWiqnXn.m4m4mmmJkwnYi5k8mhkynZn0hRhQkykydFjufcfSn1n2n3nzn4mcn5mhjujui6i6hRhhe2n6gwi6mkjtm5ckn7mlkwmJnEn8nXn9gcdPeJjSo.o#msoaobocodoeQtiFmSofogohoiojokolkWnOnNnMomonooopoqorosjMothJoumlkdovowkGm3oxoymkgxjNozmJn5oAoBoCoDltoEkJh4oFoGoHQtQtQtQt",
"QtQtQtQtQtoIoJoKQtQtf8lMoLoeoMQtQtl8lLoNoOoPoQeKi2ksoRjUi5cpm9oSeKoTnYckmKn7mloUoVoWkejKluhQhQhRjPgrnxoXoYlmoZhnkroQjzo0o1o2hcjulTi6frgymdiQkemgn8nEo3m5nEnwnEh4oYo4o5dbkGkvh4o6j#kfo7o8oco9jil8npp.p#papbpcpdpepfpgphj7pipjpkplpmpnjKorhLmaltjMgxpopporpqhQi6mihJprh.g3eCgpiwcspsptm4pumepvkJpwpxf8QtQtQt",
"QtQtQtQtpypzpAlhQthrkVoIpBpCpDQtkVjgmTpEpFpGnUfTpHiyjUkulonCdGddpIi2hnjVlxmljskGpJpJltiTmJkei6fclvgYpKmcmmozkdpLovk7pMpJmnfTispNfGnAfrhPfijOmkpOoWpPpOpok9fTpQpRpSdElTkwlVlVpTjVjUkfpUpVplpWpXpYpZp0p1p2p3p4p5p6p7p8p9q.q#qaococqbqcfah0hLjMkGkEfNhbhThcqdh.kFi6ppqecLcVdekyowqfiyn.mKmJermnnFqgqhqiQtQtQt",
"QtQtQtQtlfqjqknOQtqlqmqnqoqpqqqrqsqtl4quqvqwnagAh6qxo6jSlylVqynYf.hbqzhcpslnjSlrkwnwoWlvpqjLk8qApQiPk8ovmhozk8gxltgxltltmkmGlsi2ikqBjMfcqChjm6i5qDh4ksqEqAqFh7dEjunYmfn.n#mnlykvkLbsqGqHqIocqJqKpiqLqMqNqOqPqQqRqSqTqUqVqWqjococqXqYqZq0dFmIq1h0dHe7fcfce9cPq2oyltmnoAlThPltoWoWn6jKq3mJmloEo2q4q5q6QtQtQt",
"QtQtQtlMq7ocq8q9r.r#rarbrcrdrerfrgiHrhrirjrkj#h5o.kth4rlrmlxn.m4erh6fGifcTcMgslurmpvkKrnorpqkpo2kGgrk8hPhQhQkCmhgxmhk7kekemhmkken5rorpgxrqhlrqegrrrsh#bqcSfHrtouoUmmmmmmpurukIlzjVrvrvrwrxryocrzl0.qrArBrCrDrErFrGrHrIrJococococrKrLrMo3rNeDdGrOkArPrQrRrSfSeDg2nxo3pskxfckCgwkdmirToVnEerrUrVrWrXrYQtQtQt",
"QtQtQtj4qJocqVrZr0r1r2r3r4r5r6r7r8r9qWs.s#sasbscsdsesfsgshmfmmmllwj.hAsinYsjnAcoigsksldFnBsmsnhQkekCgrkGsokrfBspegnUfBjJmijsm6mki6cksqsrgkihiShVcobQf.owqZssoyh6m5mlmJmJm4lwqym3iPnXstsusvocmwswQtQtQtQtsxsyszsAsBoKsCsCsDocsEsEocsFsGnvg9echSpMsisHsIsJsKsLe6jug1n1n5g9eckymhk7pplylssMnyg3jssNsOrYQtQtQt",
"QtQtQtsPocqjococsQqlsRsSsTsUsVsWlhsXsYocsZs0s1s2s3s4s5s6s7s8mLs9mernkGnYn8n8s9nwgxhQecgot.eKhQgggri5t#mMq2tacpcPcTcOtbtctdtefikGm6grtftgdiaEdHfrmhi5kGmgmgozm0snn8n7kwkwmJthtilrm3jReMtjtktlmWQtQtQtQtf8tmtntotpswtqnPl0l4trqVtstttutvtwtxfctytztAtBtCtDtEtFtGlTe8fStHhalTh2grm6m4ksoArTgxptmftItJrYQtQtQt",
"QtQttKtLqJsEoctMf8QtQtQttNtOtPtQsCtRtStTtUtVtWtXtYtZtZt0t1t2t3t4t5pvkGlsn8kGkxjthOoWgrrOt6hOfrhRprt7t8t9bn#5e7dFfrdFe7ifbQcnu.u#pThQh2i9tghOfrhimhmhgxjtkxoznCuapolsmlkwmJmmubruucm2udueufugQtQtQtQtf8kSmSuhnqsCuinPl4j4l3ujukocsEulocumunuoupuqurusutuuuvuwuxuyjMhSn1uzfrmhnYucuAuBuCuDuEuFuGuHuIrYQtQtQt",
"QtnMuJuKuKocuLkVQtQtQtnjuMuNuOoKphuPj6uQuRuSuTuUuVuWnPuUuWuXuYuZu0u1nwn8nwpJoWltgxhQhPh9hje7m6t.u2u3u4n7m6kCggggggggkCmhk8h2t#fOu5jJkekzi2u.eci6hQhimhltoWltjsu6lxm5n7mlkwmmkwu7kpu8iwu9v.v#QtQtQthrkSiGlhnqoKuinPl4mWmVvanrvbvcukvdvevfvgvhvivjvkvlvmvnvovpvqvrvsf.nZn6fghRvtvuvvvwvxvyvzvAvBvCvDvEQtQtQt",
"kYvFvFvGvFq8vHQtQtQtnjvIpZvJoKnNvKl5vLvMvNhrkSvOl3jmiIjkmztKtSvPvQvRvSnwmgkxltgwmkh2rOvTdeh2rqvUbQbJhdmdh2hRfrh2fcdFi6kydGrTvVfabQ.Eksh2tfvWjtm8grhQmkgxmhpLvXqxvYnvpnoUsinEm4vZv0fCmmv1v2v3QtQtf8npiGlhnqsCuinPl4mWldl2jltKsPv4v5v6v7v8v9w.w#wawbwcwdwcwewfwgwhwig0hjpTwjwkwlwmwnsCwooLwpwqwrwswtwuQtQtQt",
"mUkUmRwvwwwxcwQtQtnjwywztRj5nNvKmysDwArIQtQtQtQtwBiIwCl5wDlMpywEwFwGwHvSpJoWgxmhkCkyn4g9h1pvwIcofcnDdFu4eJwJwKwLwMwNwOwPkyiuhxe7grbpm9wQnAi3sohSi6kyketGwRwSwTwUwVwWwXwYwZw0w1w2f4n.nFw3w4w5Qt.qnpiGlhnqsCuinPl4mWmVl2jlkYmCw6w7w8w9x.x#aDxaxbxcxdxexfxexgxhxixjxkbog4oTxlxmxnQtQthrxoxpxqlMxrxsxtQtQtQtQt",
"QtQtQtxutLjkQtQthrxvwznqoKnNuPj7lfpzjhiFQtQthrxwvKjml0QtQtQthrxxjlxyxzxAxBgxmhmki6i5i3m6tfxCdLm8i6i6ifnZxDxExFxGxHxIxJucxKkFdLm6hQhRf#xLpoluxMecjLtGxNxOt2xPxQxRxSxTxUxVxWxXjQh1pukIkFxYxZx0x1wBiGlhnqsCuinPx2mWldl2nMx3x4mvujx5x6x7mKfKx8x9y.y#yaybycydyeyfygyhyifJhPyjykylwzQtf8ymynyoypiFyqyrystRQtQtQt",
"QtQtQtwzoJphQtnjwylMnqj5nNl0l4nMytnhkZQtQtiFwByuyvywyxyuQtl8lMtRyyyzyAyByCmkhPhQh2nZmce7m9eJjui6h2dGyDyEyFyGyHyIyJyKyLyMyNn8yOh2frhQe8hxkroVyPkDyQyRySyTyUyVyWyXyXnoyYyZy0y1y2y3y4lxy5y6y7w5eliGlMjfpynOy8l0l3j4y9iIkYlJz.lKz#zazblSfLbPzczdzezfzgzhzizhzjzkzlzmx8fam8znzozptRQtzqzrzsztzuzvswzwzxq9QtQtQt",
"QtQtQtQtzywD.qlIwztRj5nNl0vHj4zzocpXjhQtf8zAzBzCzDzEzFzGzHzIswnNzJzKzLzMzNzOhihQfcnFjKfLkEdLfrdGe9zPzQzRzSzTzUzVzVzWzXzYzZz0z1z2jLfrkAifz3n5jTz4z5z6wEz7wDphmUmVz8z8z8xuz9A.A#AaAbAcucAdAeAflIiGrIAgnMoetKkZAhzyz.nMlJmvlKAiAjAkAlhRgyfaAmAnAoApAqArAsAtAuAvAwAxAybUAzAAryABACADAEAFAGAHAIAJzwqkqJpXwzQtQt",
"QtQtQtQtAKzqhrALAMoKnNl0yykXjmpzocvFANmSnjjgAOAPAQARASATAUswuij6sPniqKocAVwRk7kAe7nFjOhagydHdGe9tyAWAXAYAZA0A1A1A1A0A2A3A4A5A6A7#5m8jLnAfDkvA8A9B.B#cwQtQtf8nqjmjkBamCl7vaiIjlBbBcBdBeBfBgBhBiy9lgzwBjvamUmVxpBknKBllKmQwCBmBnBouoBpgrcTwjBqBrBsBtBuBvBwBxByBzBABBdLrQBCococBDBEBFBGBHBIBJBKBLococsEmWQtQt",
"QtQtQtQtQtBMBNBOBPBQBRBSmUmUq9ttocttBTlfrHBUBVBWBXBYBZB0B1B2B3tMpjzxococB4B5pLoWk7lyjKgefcecdHgmB6B7B8B9C.C#CaCaCaC#CbwgCcCdCeCfCgdHfcjMm8ChCiCjCkQtQtQtQthrQtClzwBaswnpelkSuikYCmCnCoCpCqCrl6Csj7tRnOl3l3x2l3vHmUlJCtCuCvCwCxCyCzCAi6CBauCCCDCECFCGCHCICJCKCLCM#aeqCNCOococqUCPQtQtCQCRCSAMiHodocttsDiFQt",
"QtQtQtQtQtQtCTCUCVCWCXCYl7xpCZocococsEqJC0C1C2C3C4C5C6C7C8C9vMD.D#ttococDaDbDcanhgg7rOfhcofKgnwjDdDeDfvlDgDhDhDiDiDhDjDkDlDmDnDoDpDq#5ecDrDsDtDuzvQtQtQtnjkSnPz8nMkSQtQtQtiFkVy8l6DvDwDxDyDzDAiGQtQtf8mAmCujkZmWl3ldoIDBDCDDDEDFDGDHDIDJDKDLDMDNDODPDQDRDSDTDUDVDWDXDYDZoctrmSQtQtD0D1D2D3D4uiBjqaocwwqUzv",
"QtQtQt.qD5D6D7D8D9E.E#EaEbEcEdococqjocEevaEfcHrAEgEhEiEjEkElwDlgqJocococEmEnEofHa3fhuzivgskxgxEpEqErEsEtEuEvEwExweEvEyEzEAEBECEDEEA7fLptEFEGEHEImSQtQtiFwBphEJEKmRBamSQtelmxnqswujELEMENEOEPlNQtQt.qiFnpxpl7EQiFhrEQj4lfERESETEUEVEWEXEYEZifE0E1E2E3E4E5E6E7E8E9F.F#FaFbFcy9QtQtnjmSjgFdy8x2z8l5Fetsrztrz.",
"QtQtQtFfFgFhFiFjFkFlFmFnFoFpFqsEqJocukl4QtQtQtQtFrFsFtFuFvsCoKpyrhsEqVqJocFwFxFydGrNhahNdEdcbqfHFzDgFAFBFCFDFEFFFFFDFDFGFHwcFIFJFKe9bSe7FLocFMsQlHQtiFlIiGFNFOodj3trFPFQmxnqtqy8pYr9vcFRFSFTlIQtQtnjFUl1q9nPnpQtcwEQAKpYFVFWFXFYFZF0F1F2F3F4F5F6F7F8F9F8G.G#GaGbGcGdGeGfGgwBQtnjmSzvsCD4l4z8xpoel6nhjliFkV",
"QtQtQtGhGiGjGkGlGlGmGnGoGpGqvcvcD#ttx4QtQtQtQt.qqiGrGsGtlNClj8l0j6wAocqKqVpkGuGvGwtflxh2GxdrGy#BGzGAGBGCGDGEGFGFGFGGxeGHGIGJFGGKGL#Z#WGMGNocqaGOj5QtwyrHxqGPGQGRGSGTGUGVvJCll0iHsQGWD.ocGXGYwyQtwBvIGZG0G1G2G3QtlMswtqG4G5G6G7G8G9H.H#vKmyj4z8z8z8z8z8z8z8z8z8z8z8HaHbEJHcQtiFEQzvsCD4l4kXxpmzlJmvHdFUQtQt",
"QtQtQtHeHfHgHhHiHjHkHlHmHnukukukqVvbf8QtQtQtf8wBEQHotRswtqj6x2mWl5iInhocttHpocHqHrHsHtHuHvHwHxHyHzHAHBHCHDHEHFHGHFHEHHHIHJHKHLHMHNHOHPHQococD.HRrhf8lHHSHTHUHVHWHXHYHZH0H1H2x2lgH3ytococplH4sCQtH5H6H7H8H9I.I#IaD3uil3vLIbocIcIdIeIfl8QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtlHtKQtIgzvoKD4l4kXxpmzx4mQIhIi.qQtQt",
"QtQtQtQtQtwBsBIjIkIloIImInInzxtLzxvHQtQtQtf8npEQwztRsCtqj6x2l5mUAgmVIorZIpIqIrIsItIuIvIwIxIyIzIAIBICIDybIEIFzfIGzfIHIIIJIKILIMINIOIPIQIRocococrZytleClISITIUr4IVIWIXIYIZI0I1I2InytD.ocococq8I3lII4I5I6I7I8I9J.J#JaAgsQq#vcocJbJcJd.qQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtJeklJfJgnNl4z8AgJhx4JiJjJkJlQtQtQt",
"QtQtQtQtQtQtQtQtQtQtlHmAnNmAJmvGvbJnQtQt.qwBEQwztRswtqj6x2l5mVAgjliImRJoJpJqJrJsJtJuJvJwkXy9kXJxJyJzJAJBJCJDJEzgJEJFJGJHJIJJJKHBJLzcJMJNococococqJocJOuhJPJQJRJSJTJUJVJWJXmzpXqVD.ococococttvcpAJYJZJ0J1J2J3J4J5J6oJqJrZococEmnrQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtFQJ7J8J9K.K#Kax3KbKcKdKeKfQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtBjukw6QtQt.ql8mSwzwDswtqj6x2l5mUAgtKx3mCBkKgKhKiKjKkKlQtQtelvaldjfmSKmKnKoKpKqKrKsKtKsAvKuKvKwKxKyKzKAavKBKCococqjococlGEQQtQtQtKDKEKFKGKHKIlEwziHqkococococqjoctssQzAb2KJKKKLKMKNKOKPmVq7ocococqjkTQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtKQKRKSKTKUKVKWKXKYKZK0K1K2K3K4K5.qQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtsCK6myQtf8l8EQwztRswtqj6lLl5mVAgjlmzlJmvx4K7K8K9L.L#QtQtl8LaCtLbiFhrmxiKLcLdLeLfLgLhLiLjLkLlLmLnLoAwLpLqLrqjsEsEttocCt.qQtQtQtQtQtLsLtLuKItRlNmToKvHmwocqJqJqVocwAQtQtQtQtLvLwLxLyvJoKpyl5LzocqJttpXuPQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtLALBLCLDLELFLGLHLILJLKLLLMLNLOLPLQLRQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQt.qvLtqQtwBmSwztRsCtqj6lLl5mUAgiIjkoImvlKmvLSLTLUocCtQtLVLWLXLYLZL0ElrIAhL1L2L3L4BxL5BxL6L7L8L9AtM.M#MaMbocD#qWqWocMckVQtQtQtQt.qnjMdMeMfMglNmAD4l0D4BavGqJD#qjD.uJjkQtQtf8dVMhMivJsCuiuPphBkvGqJqVqWnhvHQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtFQMjMkMlMmMnMoMpMqswMrMsMtMuMvMwMxelQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtj7kWhrmSlMwDswClj8x2l5mVAgjlx3lJmvG4jjMyMzMAMBocIbMCMDMEMFMGMHMIMJMKHdqKMLMMMNMOMPMQMRMSCDMTL7MUMVMWMXvGvFq8vcMYD4QtQtQtQt.qcwMZiGMfnqswmTD4uPmymWl4M0tsttocntwwqWpYiFelmSM1M2oKphvKmyj4l3sDqjqVuKvFq8nMnjQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtM3M4M5M6M7.qQtQtQtqlM8M9N.mxQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtelj8QtuhwDlNtqj6x2vHmUAgiIN#NamvjhwCNbNcNdNeNfococNgNhNiNjJSNkNlNmH3ocococNnNoNpCICINqNrNsMPNtNuNvNwvcNxMYuJqKlFQtQtQtQtQtcwJnlHlhtRswmTD4uPmymWldldnModqJqWvcuKwwqKAhJnlMnqoKphvKmyxunry9x4InqaNyNzNAlelHQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtNBNCNDNENFNGNHNImUy9iIx3NJujNKNLNMNNCwAgNOqjocqjNPNQQtNRNSNTNUNVmWGNocqjNWNXNYNZN0N1N2N3N4N5N6N7N8N9O.O#OaObj5QtQtQtQtcwJnlHlhtRswmTD4uPmymWmVAgtKAgCtFMukOcmztKkYnrjfwDoKphvKiHxunroekZnMANuklgQtQthrhrQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtOdOeOfOgOhOiOjOkkZOlAhOmOnOoOpOqOrOsOtOuvcocIohrQtQtOvbFOwOxphmAx3vGqjOyOzOAOBOCODOEOFOGOHOIOJOKOLOMONukzKf8QtQt.qnjJnlHlhtRlNmTD4uPmymWmVAgiImzx3l6pjrZkUQtf8kVvOnqoKphuPiHz8nroekZBjBaj3Eey9QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtOOOPOQOROSOTOUOVOWOXmQOYOZO0O1O2O3O4O5O6O7O8O9pXwDQtQtnjEQP.lNP#l0mWiHsDttOuPaPbPcPdPePfPgPhPiPjPkPlDcPmPnPomCQtQt.qnjJnlHlhtRlNmTD4uPmymWmVvatKkZBaBkAhGOukl2f8mSlhnqoKphuPiHxuy9oemzBjmvujlgPpzvQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtPqPrPsPtPuPvPwPwPwPxPyPzPAPBPCPDFkPEPFPGPHPIPJPKPLPMQtQtiFEQjfPNphj7j4vaAgw6POPPPQPRPSPTPUE2PVPWPXPYPZP0P1EoP2P3P4QtQtnjJnlHlhtRlNmTD4l0mymWmVAgtKmzBaBkw6ujwvNyj5JnlhnqoKuiuPiHz8y9tKmzBjujG4pYnKsPQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtP5P6P7P8P9P8Q.Q#QaQbQcQdQeQfQgQhQiQjQjQkQjQlQmQnQoQpQtiFlIjfrIphj7mWnrjlkYQqQrQs..QuQvQwQwQxQyQzQAQBQCQDQEQFQGQHQIQtcwJnlHkWtRswmTD4uPmymWmVAgtKkZmCx4w6G4pYJmGYiGvOtRoKphvKmyxunroemzBjujjhzyjhNzQJQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQKQLQMQNQOQPQQQRQSQTQUpyQVAMQWQXQYQZQ0Q1Q2Q3Q4Q5Q6QtlIjgsCphlLmWy9jlmCw6x4Q7Q8Q9R.R.R.R.R.R.R.R.R#RaRbRbRbRcRdRe.qJnlHlhtRswmTD4l0myj4mVAgiIkZBaBkz.lKzylKnsRfRgRhRiRjnPmyj4nroekZRkAhJjRlRmRnRoQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtALRpRqRrRsRtRuRvlNQtQtQtQtQtRwRxRyRzRARBRCrIRDREhrjfJwRFlLmWy9jlmCRGRHRIRJCluiuiuiuiuiuiuiuiuiuiuiuiuiuioKj4qL.qmxkWtRlNmTy8uPmymWldvatKx3mCBkw6G4wCwCRKRLRFyyRMRNRORPRQRRtKx3NaRSRTRURVRWRXQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtcwelelhrQtQtQtQtQtQtQtQtQtQthrhrQtQtQtQtRYRZBPR0R1R2k1iIR3R4R5R6R7R8Qtf8f8f8f8f8f8f8f8f8f8f8f8f8f8.qhrR9wylhAKswmAS.l0mymWmVAgtKmzmCx4z.yxS#zwSaSbScSdSeSfSgShSiSjSkMKmQSlSmSnSoSpSqSrSsStSuQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtSvSwSxSySzSAkYSBSCSDSESFSGSHLAQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtSISJSKSLSMSNSOSPl5mUvatKkZBaMKSQSRSSSTSUSVSWSXSYSZS0S1S2S3S4S5S6S7S8S9T.T#TaTbTcTdTeTfTgQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtThTiTjTkTlTmTnToRSTpTqTrTsTtTuTvTwTxQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtEjTyTzTATBTCTDTETFmzBjBkSQTGTHTITJTKTLTMTNTOTPTQTRTSTTTUTVTWTXTYTZQiT0T1T2T2T2T3T4T5T6QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtT7T8T9U.U#UaUbUcUdUeUfUgUhUiUjUkUlUmQtQtQtQtQtQtQtQtQtQtQtQtQtUnUoUpUqUrUsUtUuUvUwUxUyUzEczyUAUBUCUDUEUFUGUHUIUJUKULUMUNBHUOUPUQURJYUSUTUUUVUWUXUYUZU0U1U2QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtU3U4U5U6U7U8U9V.iFQtV#VaVbVcVdVeVfl8QtQtQtQtQtQtQtQtQtQtQtQtVgVhViVjVkVlVmVmPtVnVoVpVqVrVsVtVuVvVwVxVyVzVAVBVCVDVEVFVGVHVIVJVKf8QtQtQtCPVLVMVNVOVPVQVRyqQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtnjVSVTVUhrQtQtQtQtQtJnVVCPf8QtQtQtQtQtQtQtQtQtQtQtQtQtQtVWVXVYVZV0V1V1V1V2V3V4V5V6V7V8V9W.JTW#WaWbWcWcWbWdWeWfWgWhkVl8QtQtQtQtQtQtQtQtQtnjwBcwQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtWiWjWkWlBHWmWnWoBHWpWqWrWsiIl7z8WtWuWvWwUYUWUXUYWxWlWyWzWAQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtiGWBWCWDWEWFWGWHWIWJWKlNQtQtQtQtPNWLWMWNWOWPWQWRWSWTlLelQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtEQWUWVWWWWWXj8wzhrQtQtQtQtQtQtQtEQsCWYWZW0mTwznjQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};

static const unsigned char img9_aboutDlg[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x45, 0x00, 0x00, 0x00, 0x35,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x17, 0xaf, 0x26, 0xe8, 0x00, 0x00, 0x02,
    0xf7, 0x49, 0x44, 0x41, 0x54, 0x68, 0x81, 0xed, 0x9b, 0x3d, 0x6e, 0xdb,
    0x30, 0x18, 0x86, 0x1f, 0x0a, 0xdd, 0xe3, 0x9c, 0xa0, 0x85, 0x2f, 0x10,
    0x17, 0x39, 0x40, 0x23, 0xc0, 0x9d, 0x9b, 0x25, 0x9d, 0xc3, 0xa5, 0x1d,
    0xdb, 0x2d, 0xde, 0xea, 0x6c, 0xc9, 0xe6, 0x8e, 0xc9, 0x42, 0x67, 0x6d,
    0x86, 0xe4, 0x00, 0x41, 0xe5, 0x1e, 0xc0, 0x40, 0x73, 0x01, 0x23, 0x3d,
    0x41, 0x93, 0x13, 0xb0, 0x43, 0xa8, 0x54, 0x91, 0x69, 0x39, 0x26, 0x69,
    0xc9, 0x96, 0xf5, 0x00, 0x01, 0x02, 0x89, 0x7a, 0xf9, 0xe9, 0x15, 0x7f,
    0x3e, 0x1a, 0xa4, 0xd0, 0x5a, 0x33, 0x0f, 0x21, 0x93, 0x37, 0xc0, 0x3e,
    0xd0, 0x9a, 0x55, 0x46, 0xab, 0xb8, 0x6f, 0xca, 0xf6, 0xe7, 0x0a, 0x56,
    0xc7, 0x48, 0xab, 0x78, 0x34, 0xaf, 0x90, 0x28, 0x32, 0x45, 0xc8, 0x64,
    0x1f, 0xe8, 0x03, 0x3b, 0xf3, 0x84, 0xb4, 0x8a, 0x85, 0x79, 0x66, 0xbe,
    0xcb, 0xd5, 0xf2, 0x00, 0x0c, 0x80, 0x81, 0x56, 0xf1, 0xbd, 0xad, 0x40,
    0x64, 0xbb, 0x28, 0x64, 0xd2, 0x12, 0x32, 0x19, 0x01, 0x57, 0xbc, 0xc0,
    0x90, 0x35, 0x63, 0x0b, 0xf8, 0x06, 0xdc, 0x99, 0x8f, 0x3e, 0xc5, 0x94,
    0x29, 0x42, 0x26, 0x1d, 0x60, 0x04, 0xbc, 0x5b, 0x6a, 0x68, 0xd5, 0xb3,
    0x05, 0x5c, 0x09, 0x99, 0x1c, 0xe6, 0x6f, 0x3c, 0x33, 0x45, 0xc8, 0xa4,
    0x05, 0x0c, 0xa9, 0x5f, 0xeb, 0x28, 0x42, 0xe5, 0x8d, 0xc9, 0xb7, 0x94,
    0x6b, 0x36, 0xcb, 0x90, 0x14, 0x65, 0x7a, 0x08, 0x90, 0x31, 0xc5, 0xb8,
    0x55, 0xf7, 0x2e, 0x53, 0xc4, 0x30, 0xfd, 0x27, 0xdb, 0x52, 0xfa, 0xa5,
    0x87, 0xb1, 0x5a, 0xec, 0xa4, 0xdd, 0x28, 0x82, 0xa7, 0x56, 0xf2, 0xba,
    0xc2, 0x80, 0x56, 0x85, 0x3e, 0x98, 0x3c, 0x45, 0xc8, 0xe4, 0x1a, 0xf8,
    0xe0, 0xa2, 0x92, 0xe6, 0x27, 0xab, 0x86, 0x47, 0xbe, 0xf4, 0x36, 0xed,
    0x3e, 0xb5, 0x32, 0x04, 0xbc, 0x62, 0xdb, 0x8f, 0xb2, 0xa3, 0x6e, 0x49,
    0x95, 0x96, 0x86, 0x63, 0x8c, 0x9d, 0x88, 0x82, 0xf5, 0xcc, 0x86, 0xd2,
    0x6a, 0x4c, 0xb1, 0x60, 0x5d, 0xfb, 0x6c, 0x3a, 0x11, 0x60, 0x5d, 0x29,
    0x6e, 0x32, 0x4d, 0x4b, 0xb1, 0xd0, 0x98, 0x62, 0xa1, 0x31, 0xc5, 0x42,
    0x63, 0x8a, 0x85, 0xc6, 0x14, 0x0b, 0x8d, 0x29, 0x16, 0x1a, 0x53, 0x2c,
    0x34, 0xa6, 0x58, 0x78, 0x15, 0x42, 0x44, 0xc8, 0xa4, 0x0b, 0x9c, 0x01,
    0x6d, 0x0f, 0x99, 0x9e, 0x56, 0xf1, 0xa9, 0xd1, 0x3b, 0x02, 0x8e, 0x80,
    0x6d, 0x0f, 0xbd, 0x1b, 0xad, 0xe2, 0xf7, 0x2e, 0x0f, 0x7a, 0x9b, 0x22,
    0x64, 0xd2, 0x06, 0x7e, 0xe0, 0xf7, 0x02, 0x59, 0xbd, 0x2e, 0x70, 0x12,
    0x42, 0xcb, 0x95, 0x10, 0xdd, 0xc7, 0xf7, 0x8b, 0xe6, 0x39, 0x08, 0xa8,
    0xe5, 0x44, 0x08, 0x53, 0xba, 0x01, 0x34, 0xb2, 0xf8, 0x74, 0xc1, 0x20,
    0x84, 0x18, 0x53, 0xf2, 0x2f, 0x31, 0x01, 0xce, 0x1d, 0x74, 0xc6, 0x05,
    0xf7, 0x7a, 0x73, 0xee, 0xdb, 0xf8, 0xeb, 0x10, 0x03, 0x10, 0x68, 0xa0,
    0xcd, 0x31, 0x49, 0x07, 0xcc, 0x80, 0x8c, 0xb5, 0x8a, 0x6f, 0x02, 0x6b,
    0xce, 0xa4, 0x99, 0x92, 0x2d, 0x2c, 0xa3, 0xa5, 0x2c, 0x83, 0x03, 0x21,
    0x93, 0xdd, 0x17, 0x96, 0xbd, 0xd4, 0x2a, 0x9e, 0xf8, 0x54, 0xb6, 0x2e,
    0xa6, 0x7c, 0x5a, 0xa0, 0xec, 0x89, 0x90, 0xc9, 0x67, 0xad, 0x62, 0x97,
    0x71, 0x0d, 0xa8, 0x6f, 0xf7, 0x39, 0x33, 0xf9, 0x93, 0x13, 0x75, 0x35,
    0x05, 0x3c, 0xf2, 0x9d, 0x75, 0xe9, 0x3e, 0x63, 0x8a, 0xa7, 0xd8, 0x36,
    0xd3, 0xa9, 0x41, 0x17, 0x70, 0x9a, 0x05, 0xd7, 0xc5, 0x94, 0x5e, 0xd1,
    0x94, 0x6c, 0xd6, 0x4a, 0xc1, 0x96, 0x06, 0xcb, 0x30, 0xa5, 0x6d, 0x82,
    0x5c, 0x94, 0xa2, 0x5c, 0x64, 0x57, 0xc8, 0xa4, 0xb0, 0x4e, 0x87, 0xfa,
    0x66, 0x12, 0xc2, 0x94, 0x09, 0xcf, 0x83, 0x6a, 0xe3, 0xf6, 0xd5, 0x7a,
    0xc0, 0x8d, 0xd1, 0xcb, 0xe3, 0xa2, 0xe7, 0x3c, 0x2d, 0x87, 0x18, 0x68,
    0x43, 0x67, 0x9a, 0xa1, 0xf4, 0x16, 0x5d, 0x16, 0x3c, 0x11, 0xc2, 0x94,
    0x53, 0x3c, 0xd6, 0x19, 0x79, 0xb4, 0x8a, 0x2f, 0xf1, 0xf8, 0xca, 0x86,
    0x71, 0xa5, 0x79, 0x8a, 0xc9, 0x1e, 0x3f, 0xe2, 0xff, 0x22, 0x59, 0x7c,
    0xf4, 0xce, 0x01, 0xa7, 0x1f, 0x97, 0x52, 0x04, 0x87, 0x3f, 0x5b, 0x38,
    0x7e, 0xe9, 0x55, 0xdf, 0x8e, 0xe1, 0xb8, 0x71, 0xe7, 0x7b, 0x64, 0x76,
    0x1d, 0xff, 0x29, 0xb1, 0xd2, 0x52, 0xf0, 0x88, 0xed, 0x77, 0xba, 0xbd,
    0x6b, 0x00, 0x7c, 0x09, 0x19, 0x54, 0x15, 0x04, 0xda, 0x0a, 0xbf, 0x9d,
    0x8e, 0x29, 0x03, 0xff, 0x90, 0x6a, 0xc1, 0x85, 0x56, 0xf1, 0x7d, 0x04,
    0xa0, 0x55, 0x7c, 0x07, 0x5c, 0x54, 0x1b, 0xcf, 0x4a, 0xd0, 0x87, 0xe9,
    0x7d, 0xb4, 0x0f, 0x55, 0x44, 0xb2, 0x22, 0x1c, 0x9b, 0xc6, 0xf1, 0xdf,
    0x14, 0x73, 0xe1, 0x6b, 0x45, 0x01, 0x55, 0xcd, 0x6d, 0x7a, 0x5e, 0x09,
    0x72, 0x79, 0x8a, 0x56, 0xf1, 0x10, 0x38, 0x2e, 0x39, 0xa0, 0xaa, 0xb9,
    0x05, 0xf6, 0xb2, 0x17, 0xa6, 0x92, 0x37, 0xe3, 0x98, 0x2c, 0x27, 0x9e,
    0xca, 0xb9, 0x05, 0xf6, 0xf2, 0x87, 0xa1, 0xac, 0x19, 0xad, 0x69, 0x31,
    0xb1, 0x79, 0xa8, 0x8e, 0x3c, 0xf0, 0x38, 0x86, 0x74, 0x6c, 0xa7, 0xc3,
    0x66, 0xae, 0x92, 0xcd, 0x59, 0xbb, 0x8e, 0x39, 0x3d, 0x95, 0xfe, 0x6d,
    0x2d, 0x2b, 0xca, 0x92, 0xf8, 0xc5, 0xe3, 0xf1, 0x9d, 0xe1, 0xac, 0xa3,
    0x72, 0x00, 0xff, 0x00, 0x92, 0xcb, 0xdc, 0x3f, 0xf8, 0xe0, 0x0a, 0x7f,
    0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};


/*
 *  Constructs a AboutDlg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
AboutDlg::AboutDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl ),
      image0( (const char **) img0_aboutDlg ),
      image1( (const char **) img1_aboutDlg ),
      image2( (const char **) img2_aboutDlg ),
      image3( (const char **) img3_aboutDlg ),
      image4( (const char **) img4_aboutDlg ),
      image5( (const char **) img5_aboutDlg ),
      image6( (const char **) img6_aboutDlg ),
      image7( (const char **) img7_aboutDlg ),
      image8( (const char **) img8_aboutDlg )
{
    QImage img;
    img.loadFromData( img9_aboutDlg, sizeof( img9_aboutDlg ), "PNG" );
    image9 = img;
    if ( !name )
	setName( "AboutDlg" );
    setMinimumSize( QSize( 480, 350 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    AboutDlgLayout = new QGridLayout( this, 1, 1, 0, 0, "AboutDlgLayout"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 480, 18 ) );
    textLabel1->setMaximumSize( QSize( 32767, 18 ) );
    textLabel1->setPaletteBackgroundPixmap( image0 );

    AboutDlgLayout->addWidget( textLabel1, 0, 0 );

    frame16 = new QFrame( this, "frame16" );
    frame16->setMinimumSize( QSize( 480, 21 ) );
    frame16->setMaximumSize( QSize( 32767, 21 ) );
    frame16->setPaletteBackgroundPixmap( image1 );
    frame16->setFrameShape( QFrame::NoFrame );
    frame16->setFrameShadow( QFrame::Plain );
    frame16Layout = new QGridLayout( frame16, 1, 1, 0, 0, "frame16Layout"); 

    textLabel1_2 = new QLabel( frame16, "textLabel1_2" );
    textLabel1_2->setMinimumSize( QSize( 72, 21 ) );
    textLabel1_2->setMaximumSize( QSize( 72, 21 ) );
    textLabel1_2->setPaletteBackgroundPixmap( image2 );

    frame16Layout->addWidget( textLabel1_2, 0, 2 );

    pixmapLabel1 = new QLabel( frame16, "pixmapLabel1" );
    pixmapLabel1->setMinimumSize( QSize( 180, 21 ) );
    pixmapLabel1->setMaximumSize( QSize( 180, 21 ) );
    pixmapLabel1->setPixmap( image3 );
    pixmapLabel1->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel1, 0, 0 );
    spacer8 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame16Layout->addItem( spacer8, 0, 1 );

    AboutDlgLayout->addWidget( frame16, 1, 0 );

    layout34 = new QHBoxLayout( 0, 0, 0, "layout34"); 

    frame15 = new QFrame( this, "frame15" );
    frame15->setMinimumSize( QSize( 440, 31 ) );
    frame15->setMaximumSize( QSize( 32767, 31 ) );
    frame15->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame15->setPaletteBackgroundPixmap( image4 );
    frame15->setFrameShape( QFrame::NoFrame );
    frame15->setFrameShadow( QFrame::Plain );
    frame15->setLineWidth( 0 );
    frame15Layout = new QGridLayout( frame15, 1, 1, 0, 0, "frame15Layout"); 

    layout33 = new QVBoxLayout( 0, 0, 0, "layout33"); 
    spacer37 = new QSpacerItem( 20, 15, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout33->addItem( spacer37 );

    exitButtonPlaceHolder = new QLabel( frame15, "exitButtonPlaceHolder" );
    exitButtonPlaceHolder->setMinimumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setMaximumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setPixmap( image5 );
    exitButtonPlaceHolder->setScaledContents( FALSE );
    layout33->addWidget( exitButtonPlaceHolder );

    frame15Layout->addLayout( layout33, 0, 1 );
    spacer38 = new QSpacerItem( 40, 18, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame15Layout->addItem( spacer38, 0, 0 );
    layout34->addWidget( frame15 );

    pixmapLabel8_2 = new QLabel( this, "pixmapLabel8_2" );
    pixmapLabel8_2->setMinimumSize( QSize( 28, 31 ) );
    pixmapLabel8_2->setMaximumSize( QSize( 28, 31 ) );
    pixmapLabel8_2->setPixmap( image6 );
    pixmapLabel8_2->setScaledContents( FALSE );
    layout34->addWidget( pixmapLabel8_2 );

    AboutDlgLayout->addLayout( layout34, 5, 0 );
    spacer20 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    AboutDlgLayout->addItem( spacer20, 2, 0 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 499, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image7 );
    pixmapLabel9_2->setScaledContents( FALSE );

    AboutDlgLayout->addWidget( pixmapLabel9_2, 6, 0 );

    layout117 = new QHBoxLayout( 0, 0, 0, "layout117"); 
    spacer143 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout117->addItem( spacer143 );

    aboutPlaceHolder = new QTextEdit( this, "aboutPlaceHolder" );
    aboutPlaceHolder->setMinimumSize( QSize( 300, 280 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 238, 239, 241) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    aboutPlaceHolder->setPalette( pal );
    aboutPlaceHolder->setFrameShape( QTextEdit::Box );
    aboutPlaceHolder->setFrameShadow( QTextEdit::Plain );
    aboutPlaceHolder->setLineWidth( 1 );
    layout117->addWidget( aboutPlaceHolder );
    spacer144 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout117->addItem( spacer144 );

    AboutDlgLayout->addLayout( layout117, 4, 0 );

    frame10 = new QFrame( this, "frame10" );
    frame10->setFrameShape( QFrame::NoFrame );
    frame10->setFrameShadow( QFrame::Plain );
    frame10Layout = new QGridLayout( frame10, 1, 1, 0, 0, "frame10Layout"); 

    pixmapLabel1_2 = new QLabel( frame10, "pixmapLabel1_2" );
    pixmapLabel1_2->setMinimumSize( QSize( 149, 74 ) );
    pixmapLabel1_2->setMaximumSize( QSize( 149, 74 ) );
    pixmapLabel1_2->setPixmap( image8 );
    pixmapLabel1_2->setScaledContents( FALSE );

    frame10Layout->addWidget( pixmapLabel1_2, 0, 3 );
    spacer21 = new QSpacerItem( 40, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame10Layout->addItem( spacer21, 0, 4 );
    spacer19 = new QSpacerItem( 20, 87, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame10Layout->addItem( spacer19, 0, 0 );
    spacer17 = new QSpacerItem( 155, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame10Layout->addItem( spacer17, 0, 2 );

    layout7 = new QVBoxLayout( 0, 0, 0, "layout7"); 

    pixmapLabel1_3 = new QLabel( frame10, "pixmapLabel1_3" );
    pixmapLabel1_3->setMinimumSize( QSize( 69, 53 ) );
    pixmapLabel1_3->setMaximumSize( QSize( 69, 53 ) );
    pixmapLabel1_3->setPixmap( image9 );
    pixmapLabel1_3->setScaledContents( FALSE );
    layout7->addWidget( pixmapLabel1_3 );
    spacer19_2 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout7->addItem( spacer19_2 );

    frame10Layout->addLayout( layout7, 0, 1 );

    AboutDlgLayout->addWidget( frame10, 3, 0 );
    languageChange();
    resize( QSize(500, 467).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
AboutDlg::~AboutDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void AboutDlg::languageChange()
{
    setCaption( ( "OpenC6" ) );
}

#include "aboutDlg.moc"
